# Stubs for google.ads.google_ads.v6.services.transports.reach_plan_service_grpc_transport (Python 3)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any, Optional

class ReachPlanServiceGrpcTransport:
    def __init__(
        self,
        channel: Optional[Any] = ...,
        credentials: Optional[Any] = ...,
        address: str = ...,
    ) -> None: ...
    @classmethod
    def create_channel(
        cls, address: str = ..., credentials: Optional[Any] = ..., **kwargs: Any
    ): ...
    @property
    def channel(self): ...
    @property
    def list_plannable_locations(self): ...
    @property
    def list_plannable_products(self): ...
    @property
    def generate_product_mix_ideas(self): ...
    @property
    def generate_reach_forecast(self): ...



from typing import Any

class AccountBudgetServiceStub:
    GetAccountBudget: Any = ...
    def __init__(self, channel: Any) -> None: ...

class AccountBudgetServiceServicer:
    def GetAccountBudget(self, request: Any, context: Any) -> None: ...

def add_AccountBudgetServiceServicer_to_server(servicer: Any, server: Any) -> None: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class DateErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    DateErrorValue = typing___NewType("DateErrorValue", builtin___int)
    type___DateErrorValue = DateErrorValue
    DateError: _DateError
    class _DateError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            DateErrorEnum.DateErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(DateErrorEnum.DateErrorValue, 0)
        UNKNOWN = typing___cast(DateErrorEnum.DateErrorValue, 1)
        INVALID_FIELD_VALUES_IN_DATE = typing___cast(DateErrorEnum.DateErrorValue, 2)
        INVALID_FIELD_VALUES_IN_DATE_TIME = typing___cast(
            DateErrorEnum.DateErrorValue, 3
        )
        INVALID_STRING_DATE = typing___cast(DateErrorEnum.DateErrorValue, 4)
        INVALID_STRING_DATE_TIME_MICROS = typing___cast(DateErrorEnum.DateErrorValue, 6)
        INVALID_STRING_DATE_TIME_SECONDS = typing___cast(
            DateErrorEnum.DateErrorValue, 11
        )
        INVALID_STRING_DATE_TIME_SECONDS_WITH_OFFSET = typing___cast(
            DateErrorEnum.DateErrorValue, 12
        )
        EARLIER_THAN_MINIMUM_DATE = typing___cast(DateErrorEnum.DateErrorValue, 7)
        LATER_THAN_MAXIMUM_DATE = typing___cast(DateErrorEnum.DateErrorValue, 8)
        DATE_RANGE_MINIMUM_DATE_LATER_THAN_MAXIMUM_DATE = typing___cast(
            DateErrorEnum.DateErrorValue, 9
        )
        DATE_RANGE_MINIMUM_AND_MAXIMUM_DATES_BOTH_NULL = typing___cast(
            DateErrorEnum.DateErrorValue, 10
        )
    UNSPECIFIED = typing___cast(DateErrorEnum.DateErrorValue, 0)
    UNKNOWN = typing___cast(DateErrorEnum.DateErrorValue, 1)
    INVALID_FIELD_VALUES_IN_DATE = typing___cast(DateErrorEnum.DateErrorValue, 2)
    INVALID_FIELD_VALUES_IN_DATE_TIME = typing___cast(DateErrorEnum.DateErrorValue, 3)
    INVALID_STRING_DATE = typing___cast(DateErrorEnum.DateErrorValue, 4)
    INVALID_STRING_DATE_TIME_MICROS = typing___cast(DateErrorEnum.DateErrorValue, 6)
    INVALID_STRING_DATE_TIME_SECONDS = typing___cast(DateErrorEnum.DateErrorValue, 11)
    INVALID_STRING_DATE_TIME_SECONDS_WITH_OFFSET = typing___cast(
        DateErrorEnum.DateErrorValue, 12
    )
    EARLIER_THAN_MINIMUM_DATE = typing___cast(DateErrorEnum.DateErrorValue, 7)
    LATER_THAN_MAXIMUM_DATE = typing___cast(DateErrorEnum.DateErrorValue, 8)
    DATE_RANGE_MINIMUM_DATE_LATER_THAN_MAXIMUM_DATE = typing___cast(
        DateErrorEnum.DateErrorValue, 9
    )
    DATE_RANGE_MINIMUM_AND_MAXIMUM_DATES_BOTH_NULL = typing___cast(
        DateErrorEnum.DateErrorValue, 10
    )
    type___DateError = DateError
    def __init__(self,) -> None: ...

type___DateErrorEnum = DateErrorEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class ConversionActionTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ConversionActionTypeValue = typing___NewType(
        "ConversionActionTypeValue", builtin___int
    )
    type___ConversionActionTypeValue = ConversionActionTypeValue
    ConversionActionType: _ConversionActionType
    class _ConversionActionType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            ConversionActionTypeEnum.ConversionActionTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 0
        )
        UNKNOWN = typing___cast(ConversionActionTypeEnum.ConversionActionTypeValue, 1)
        AD_CALL = typing___cast(ConversionActionTypeEnum.ConversionActionTypeValue, 2)
        CLICK_TO_CALL = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 3
        )
        GOOGLE_PLAY_DOWNLOAD = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 4
        )
        GOOGLE_PLAY_IN_APP_PURCHASE = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 5
        )
        UPLOAD_CALLS = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 6
        )
        UPLOAD_CLICKS = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 7
        )
        WEBPAGE = typing___cast(ConversionActionTypeEnum.ConversionActionTypeValue, 8)
        WEBSITE_CALL = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 9
        )
        STORE_SALES_DIRECT_UPLOAD = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 10
        )
        STORE_SALES = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 11
        )
        FIREBASE_ANDROID_FIRST_OPEN = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 12
        )
        FIREBASE_ANDROID_IN_APP_PURCHASE = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 13
        )
        FIREBASE_ANDROID_CUSTOM = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 14
        )
        FIREBASE_IOS_FIRST_OPEN = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 15
        )
        FIREBASE_IOS_IN_APP_PURCHASE = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 16
        )
        FIREBASE_IOS_CUSTOM = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 17
        )
        THIRD_PARTY_APP_ANALYTICS_ANDROID_FIRST_OPEN = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 18
        )
        THIRD_PARTY_APP_ANALYTICS_ANDROID_IN_APP_PURCHASE = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 19
        )
        THIRD_PARTY_APP_ANALYTICS_ANDROID_CUSTOM = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 20
        )
        THIRD_PARTY_APP_ANALYTICS_IOS_FIRST_OPEN = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 21
        )
        THIRD_PARTY_APP_ANALYTICS_IOS_IN_APP_PURCHASE = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 22
        )
        THIRD_PARTY_APP_ANALYTICS_IOS_CUSTOM = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 23
        )
        ANDROID_APP_PRE_REGISTRATION = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 24
        )
        ANDROID_INSTALLS_ALL_OTHER_APPS = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 25
        )
        FLOODLIGHT_ACTION = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 26
        )
        FLOODLIGHT_TRANSACTION = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 27
        )
        GOOGLE_HOSTED = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 28
        )
        LEAD_FORM_SUBMIT = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 29
        )
        SALESFORCE = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 30
        )
        SEARCH_ADS_360 = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 31
        )
        SMART_CAMPAIGN_AD_CLICKS_TO_CALL = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 32
        )
        SMART_CAMPAIGN_MAP_CLICKS_TO_CALL = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 33
        )
        SMART_CAMPAIGN_MAP_DIRECTIONS = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 34
        )
        SMART_CAMPAIGN_TRACKED_CALLS = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 35
        )
        STORE_VISITS = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 36
        )
    UNSPECIFIED = typing___cast(ConversionActionTypeEnum.ConversionActionTypeValue, 0)
    UNKNOWN = typing___cast(ConversionActionTypeEnum.ConversionActionTypeValue, 1)
    AD_CALL = typing___cast(ConversionActionTypeEnum.ConversionActionTypeValue, 2)
    CLICK_TO_CALL = typing___cast(ConversionActionTypeEnum.ConversionActionTypeValue, 3)
    GOOGLE_PLAY_DOWNLOAD = typing___cast(
        ConversionActionTypeEnum.ConversionActionTypeValue, 4
    )
    GOOGLE_PLAY_IN_APP_PURCHASE = typing___cast(
        ConversionActionTypeEnum.ConversionActionTypeValue, 5
    )
    UPLOAD_CALLS = typing___cast(ConversionActionTypeEnum.ConversionActionTypeValue, 6)
    UPLOAD_CLICKS = typing___cast(ConversionActionTypeEnum.ConversionActionTypeValue, 7)
    WEBPAGE = typing___cast(ConversionActionTypeEnum.ConversionActionTypeValue, 8)
    WEBSITE_CALL = typing___cast(ConversionActionTypeEnum.ConversionActionTypeValue, 9)
    STORE_SALES_DIRECT_UPLOAD = typing___cast(
        ConversionActionTypeEnum.ConversionActionTypeValue, 10
    )
    STORE_SALES = typing___cast(ConversionActionTypeEnum.ConversionActionTypeValue, 11)
    FIREBASE_ANDROID_FIRST_OPEN = typing___cast(
        ConversionActionTypeEnum.ConversionActionTypeValue, 12
    )
    FIREBASE_ANDROID_IN_APP_PURCHASE = typing___cast(
        ConversionActionTypeEnum.ConversionActionTypeValue, 13
    )
    FIREBASE_ANDROID_CUSTOM = typing___cast(
        ConversionActionTypeEnum.ConversionActionTypeValue, 14
    )
    FIREBASE_IOS_FIRST_OPEN = typing___cast(
        ConversionActionTypeEnum.ConversionActionTypeValue, 15
    )
    FIREBASE_IOS_IN_APP_PURCHASE = typing___cast(
        ConversionActionTypeEnum.ConversionActionTypeValue, 16
    )
    FIREBASE_IOS_CUSTOM = typing___cast(
        ConversionActionTypeEnum.ConversionActionTypeValue, 17
    )
    THIRD_PARTY_APP_ANALYTICS_ANDROID_FIRST_OPEN = typing___cast(
        ConversionActionTypeEnum.ConversionActionTypeValue, 18
    )
    THIRD_PARTY_APP_ANALYTICS_ANDROID_IN_APP_PURCHASE = typing___cast(
        ConversionActionTypeEnum.ConversionActionTypeValue, 19
    )
    THIRD_PARTY_APP_ANALYTICS_ANDROID_CUSTOM = typing___cast(
        ConversionActionTypeEnum.ConversionActionTypeValue, 20
    )
    THIRD_PARTY_APP_ANALYTICS_IOS_FIRST_OPEN = typing___cast(
        ConversionActionTypeEnum.ConversionActionTypeValue, 21
    )
    THIRD_PARTY_APP_ANALYTICS_IOS_IN_APP_PURCHASE = typing___cast(
        ConversionActionTypeEnum.ConversionActionTypeValue, 22
    )
    THIRD_PARTY_APP_ANALYTICS_IOS_CUSTOM = typing___cast(
        ConversionActionTypeEnum.ConversionActionTypeValue, 23
    )
    ANDROID_APP_PRE_REGISTRATION = typing___cast(
        ConversionActionTypeEnum.ConversionActionTypeValue, 24
    )
    ANDROID_INSTALLS_ALL_OTHER_APPS = typing___cast(
        ConversionActionTypeEnum.ConversionActionTypeValue, 25
    )
    FLOODLIGHT_ACTION = typing___cast(
        ConversionActionTypeEnum.ConversionActionTypeValue, 26
    )
    FLOODLIGHT_TRANSACTION = typing___cast(
        ConversionActionTypeEnum.ConversionActionTypeValue, 27
    )
    GOOGLE_HOSTED = typing___cast(
        ConversionActionTypeEnum.ConversionActionTypeValue, 28
    )
    LEAD_FORM_SUBMIT = typing___cast(
        ConversionActionTypeEnum.ConversionActionTypeValue, 29
    )
    SALESFORCE = typing___cast(ConversionActionTypeEnum.ConversionActionTypeValue, 30)
    SEARCH_ADS_360 = typing___cast(
        ConversionActionTypeEnum.ConversionActionTypeValue, 31
    )
    SMART_CAMPAIGN_AD_CLICKS_TO_CALL = typing___cast(
        ConversionActionTypeEnum.ConversionActionTypeValue, 32
    )
    SMART_CAMPAIGN_MAP_CLICKS_TO_CALL = typing___cast(
        ConversionActionTypeEnum.ConversionActionTypeValue, 33
    )
    SMART_CAMPAIGN_MAP_DIRECTIONS = typing___cast(
        ConversionActionTypeEnum.ConversionActionTypeValue, 34
    )
    SMART_CAMPAIGN_TRACKED_CALLS = typing___cast(
        ConversionActionTypeEnum.ConversionActionTypeValue, 35
    )
    STORE_VISITS = typing___cast(ConversionActionTypeEnum.ConversionActionTypeValue, 36)
    type___ConversionActionType = ConversionActionType
    def __init__(self,) -> None: ...

type___ConversionActionTypeEnum = ConversionActionTypeEnum



# Stubs for google.ads.google_ads.v6.proto.services.combined_audience_service_pb2_grpc (Python 3)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any, Optional

class CombinedAudienceServiceStub:
    GetCombinedAudience: Any = ...
    def __init__(self, channel: Any) -> None: ...

class CombinedAudienceServiceServicer:
    def GetCombinedAudience(self, request: Any, context: Any) -> None: ...

def add_CombinedAudienceServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...

class CombinedAudienceService:
    @staticmethod
    def GetCombinedAudience(
        request: Any,
        target: Any,
        options: Any = ...,
        channel_credentials: Optional[Any] = ...,
        call_credentials: Optional[Any] = ...,
        compression: Optional[Any] = ...,
        wait_for_ready: Optional[Any] = ...,
        timeout: Optional[Any] = ...,
        metadata: Optional[Any] = ...,
    ): ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.field_mask_pb2 import (
    FieldMask as google___protobuf___field_mask_pb2___FieldMask,
)
from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v3.proto.resources.customer_manager_link_pb2 import (
    CustomerManagerLink as google___ads___googleads___v3___resources___customer_manager_link_pb2___CustomerManagerLink,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class GetCustomerManagerLinkRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    def __init__(
        self, *, resource_name: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["resource_name", b"resource_name"]
    ) -> None: ...

type___GetCustomerManagerLinkRequest = GetCustomerManagerLinkRequest

class MutateCustomerManagerLinkRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    customer_id: typing___Text = ...
    @property
    def operations(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___CustomerManagerLinkOperation
    ]: ...
    def __init__(
        self,
        *,
        customer_id: typing___Optional[typing___Text] = None,
        operations: typing___Optional[
            typing___Iterable[type___CustomerManagerLinkOperation]
        ] = None,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "customer_id", b"customer_id", "operations", b"operations"
        ],
    ) -> None: ...

type___MutateCustomerManagerLinkRequest = MutateCustomerManagerLinkRequest

class MoveManagerLinkRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    customer_id: typing___Text = ...
    previous_customer_manager_link: typing___Text = ...
    new_manager: typing___Text = ...
    def __init__(
        self,
        *,
        customer_id: typing___Optional[typing___Text] = None,
        previous_customer_manager_link: typing___Optional[typing___Text] = None,
        new_manager: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "customer_id",
            b"customer_id",
            "new_manager",
            b"new_manager",
            "previous_customer_manager_link",
            b"previous_customer_manager_link",
        ],
    ) -> None: ...

type___MoveManagerLinkRequest = MoveManagerLinkRequest

class CustomerManagerLinkOperation(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def update_mask(self) -> google___protobuf___field_mask_pb2___FieldMask: ...
    @property
    def update(
        self,
    ) -> google___ads___googleads___v3___resources___customer_manager_link_pb2___CustomerManagerLink: ...
    def __init__(
        self,
        *,
        update_mask: typing___Optional[
            google___protobuf___field_mask_pb2___FieldMask
        ] = None,
        update: typing___Optional[
            google___ads___googleads___v3___resources___customer_manager_link_pb2___CustomerManagerLink
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "operation",
            b"operation",
            "update",
            b"update",
            "update_mask",
            b"update_mask",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "operation",
            b"operation",
            "update",
            b"update",
            "update_mask",
            b"update_mask",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["operation", b"operation"]
    ) -> typing_extensions___Literal["update"]: ...

type___CustomerManagerLinkOperation = CustomerManagerLinkOperation

class MutateCustomerManagerLinkResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def results(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___MutateCustomerManagerLinkResult
    ]: ...
    def __init__(
        self,
        *,
        results: typing___Optional[
            typing___Iterable[type___MutateCustomerManagerLinkResult]
        ] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["results", b"results"]
    ) -> None: ...

type___MutateCustomerManagerLinkResponse = MutateCustomerManagerLinkResponse

class MoveManagerLinkResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    def __init__(
        self, *, resource_name: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["resource_name", b"resource_name"]
    ) -> None: ...

type___MoveManagerLinkResponse = MoveManagerLinkResponse

class MutateCustomerManagerLinkResult(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    def __init__(
        self, *, resource_name: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["resource_name", b"resource_name"]
    ) -> None: ...

type___MutateCustomerManagerLinkResult = MutateCustomerManagerLinkResult



from typing import Any

class AdGroupCriterionSimulationServiceStub:
    GetAdGroupCriterionSimulation: Any = ...
    def __init__(self, channel: Any) -> None: ...

class AdGroupCriterionSimulationServiceServicer:
    def GetAdGroupCriterionSimulation(self, request: Any, context: Any) -> None: ...

def add_AdGroupCriterionSimulationServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
    overload as typing___overload,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v6.proto.enums.batch_job_status_pb2 import (
    BatchJobStatusEnum as google___ads___googleads___v6___enums___batch_job_status_pb2___BatchJobStatusEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class BatchJob(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class BatchJobMetadata(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        creation_date_time: typing___Text = ...
        start_date_time: typing___Text = ...
        completion_date_time: typing___Text = ...
        estimated_completion_ratio: builtin___float = ...
        operation_count: builtin___int = ...
        executed_operation_count: builtin___int = ...
        def __init__(
            self,
            *,
            creation_date_time: typing___Optional[typing___Text] = None,
            start_date_time: typing___Optional[typing___Text] = None,
            completion_date_time: typing___Optional[typing___Text] = None,
            estimated_completion_ratio: typing___Optional[builtin___float] = None,
            operation_count: typing___Optional[builtin___int] = None,
            executed_operation_count: typing___Optional[builtin___int] = None,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions___Literal[
                "_completion_date_time",
                b"_completion_date_time",
                "_creation_date_time",
                b"_creation_date_time",
                "_estimated_completion_ratio",
                b"_estimated_completion_ratio",
                "_executed_operation_count",
                b"_executed_operation_count",
                "_operation_count",
                b"_operation_count",
                "_start_date_time",
                b"_start_date_time",
                "completion_date_time",
                b"completion_date_time",
                "creation_date_time",
                b"creation_date_time",
                "estimated_completion_ratio",
                b"estimated_completion_ratio",
                "executed_operation_count",
                b"executed_operation_count",
                "operation_count",
                b"operation_count",
                "start_date_time",
                b"start_date_time",
            ],
        ) -> builtin___bool: ...
        def ClearField(
            self,
            field_name: typing_extensions___Literal[
                "_completion_date_time",
                b"_completion_date_time",
                "_creation_date_time",
                b"_creation_date_time",
                "_estimated_completion_ratio",
                b"_estimated_completion_ratio",
                "_executed_operation_count",
                b"_executed_operation_count",
                "_operation_count",
                b"_operation_count",
                "_start_date_time",
                b"_start_date_time",
                "completion_date_time",
                b"completion_date_time",
                "creation_date_time",
                b"creation_date_time",
                "estimated_completion_ratio",
                b"estimated_completion_ratio",
                "executed_operation_count",
                b"executed_operation_count",
                "operation_count",
                b"operation_count",
                "start_date_time",
                b"start_date_time",
            ],
        ) -> None: ...
        @typing___overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions___Literal[
                "_completion_date_time", b"_completion_date_time"
            ],
        ) -> typing_extensions___Literal["completion_date_time"]: ...
        @typing___overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions___Literal[
                "_creation_date_time", b"_creation_date_time"
            ],
        ) -> typing_extensions___Literal["creation_date_time"]: ...
        @typing___overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions___Literal[
                "_estimated_completion_ratio", b"_estimated_completion_ratio"
            ],
        ) -> typing_extensions___Literal["estimated_completion_ratio"]: ...
        @typing___overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions___Literal[
                "_executed_operation_count", b"_executed_operation_count"
            ],
        ) -> typing_extensions___Literal["executed_operation_count"]: ...
        @typing___overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions___Literal[
                "_operation_count", b"_operation_count"
            ],
        ) -> typing_extensions___Literal["operation_count"]: ...
        @typing___overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions___Literal[
                "_start_date_time", b"_start_date_time"
            ],
        ) -> typing_extensions___Literal["start_date_time"]: ...
    type___BatchJobMetadata = BatchJobMetadata

    resource_name: typing___Text = ...
    id: builtin___int = ...
    next_add_sequence_token: typing___Text = ...
    status: google___ads___googleads___v6___enums___batch_job_status_pb2___BatchJobStatusEnum.BatchJobStatusValue = ...
    long_running_operation: typing___Text = ...
    @property
    def metadata(self) -> type___BatchJob.BatchJobMetadata: ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        id: typing___Optional[builtin___int] = None,
        next_add_sequence_token: typing___Optional[typing___Text] = None,
        metadata: typing___Optional[type___BatchJob.BatchJobMetadata] = None,
        status: typing___Optional[
            google___ads___googleads___v6___enums___batch_job_status_pb2___BatchJobStatusEnum.BatchJobStatusValue
        ] = None,
        long_running_operation: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_id",
            b"_id",
            "_long_running_operation",
            b"_long_running_operation",
            "_next_add_sequence_token",
            b"_next_add_sequence_token",
            "id",
            b"id",
            "long_running_operation",
            b"long_running_operation",
            "metadata",
            b"metadata",
            "next_add_sequence_token",
            b"next_add_sequence_token",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_id",
            b"_id",
            "_long_running_operation",
            b"_long_running_operation",
            "_next_add_sequence_token",
            b"_next_add_sequence_token",
            "id",
            b"id",
            "long_running_operation",
            b"long_running_operation",
            "metadata",
            b"metadata",
            "next_add_sequence_token",
            b"next_add_sequence_token",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_id", b"_id"]
    ) -> typing_extensions___Literal["id"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_long_running_operation", b"_long_running_operation"
        ],
    ) -> typing_extensions___Literal["long_running_operation"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_next_add_sequence_token", b"_next_add_sequence_token"
        ],
    ) -> typing_extensions___Literal["next_add_sequence_token"]: ...

type___BatchJob = BatchJob



from typing import Any, Optional

class OfflineUserDataJobServiceStub:
    CreateOfflineUserDataJob: Any = ...
    GetOfflineUserDataJob: Any = ...
    AddOfflineUserDataJobOperations: Any = ...
    RunOfflineUserDataJob: Any = ...
    def __init__(self, channel: Any) -> None: ...

class OfflineUserDataJobServiceServicer:
    def CreateOfflineUserDataJob(self, request: Any, context: Any) -> None: ...
    def GetOfflineUserDataJob(self, request: Any, context: Any) -> None: ...
    def AddOfflineUserDataJobOperations(self, request: Any, context: Any) -> None: ...
    def RunOfflineUserDataJob(self, request: Any, context: Any) -> None: ...

def add_OfflineUserDataJobServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...

class OfflineUserDataJobService:
    @staticmethod
    def CreateOfflineUserDataJob(
        request: Any,
        target: Any,
        options: Any = ...,
        channel_credentials: Optional[Any] = ...,
        call_credentials: Optional[Any] = ...,
        compression: Optional[Any] = ...,
        wait_for_ready: Optional[Any] = ...,
        timeout: Optional[Any] = ...,
        metadata: Optional[Any] = ...,
    ): ...
    @staticmethod
    def GetOfflineUserDataJob(
        request: Any,
        target: Any,
        options: Any = ...,
        channel_credentials: Optional[Any] = ...,
        call_credentials: Optional[Any] = ...,
        compression: Optional[Any] = ...,
        wait_for_ready: Optional[Any] = ...,
        timeout: Optional[Any] = ...,
        metadata: Optional[Any] = ...,
    ): ...
    @staticmethod
    def AddOfflineUserDataJobOperations(
        request: Any,
        target: Any,
        options: Any = ...,
        channel_credentials: Optional[Any] = ...,
        call_credentials: Optional[Any] = ...,
        compression: Optional[Any] = ...,
        wait_for_ready: Optional[Any] = ...,
        timeout: Optional[Any] = ...,
        metadata: Optional[Any] = ...,
    ): ...
    @staticmethod
    def RunOfflineUserDataJob(
        request: Any,
        target: Any,
        options: Any = ...,
        channel_credentials: Optional[Any] = ...,
        call_credentials: Optional[Any] = ...,
        compression: Optional[Any] = ...,
        wait_for_ready: Optional[Any] = ...,
        timeout: Optional[Any] = ...,
        metadata: Optional[Any] = ...,
    ): ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import Optional as typing___Optional, Text as typing___Text

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from google.protobuf.wrappers_pb2 import (
    DoubleValue as google___protobuf___wrappers_pb2___DoubleValue,
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v4.proto.enums.batch_job_status_pb2 import (
    BatchJobStatusEnum as google___ads___googleads___v4___enums___batch_job_status_pb2___BatchJobStatusEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class BatchJob(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class BatchJobMetadata(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        @property
        def creation_date_time(
            self,
        ) -> google___protobuf___wrappers_pb2___StringValue: ...
        @property
        def completion_date_time(
            self,
        ) -> google___protobuf___wrappers_pb2___StringValue: ...
        @property
        def estimated_completion_ratio(
            self,
        ) -> google___protobuf___wrappers_pb2___DoubleValue: ...
        @property
        def operation_count(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
        @property
        def executed_operation_count(
            self,
        ) -> google___protobuf___wrappers_pb2___Int64Value: ...
        def __init__(
            self,
            *,
            creation_date_time: typing___Optional[
                google___protobuf___wrappers_pb2___StringValue
            ] = None,
            completion_date_time: typing___Optional[
                google___protobuf___wrappers_pb2___StringValue
            ] = None,
            estimated_completion_ratio: typing___Optional[
                google___protobuf___wrappers_pb2___DoubleValue
            ] = None,
            operation_count: typing___Optional[
                google___protobuf___wrappers_pb2___Int64Value
            ] = None,
            executed_operation_count: typing___Optional[
                google___protobuf___wrappers_pb2___Int64Value
            ] = None,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions___Literal[
                "completion_date_time",
                b"completion_date_time",
                "creation_date_time",
                b"creation_date_time",
                "estimated_completion_ratio",
                b"estimated_completion_ratio",
                "executed_operation_count",
                b"executed_operation_count",
                "operation_count",
                b"operation_count",
            ],
        ) -> builtin___bool: ...
        def ClearField(
            self,
            field_name: typing_extensions___Literal[
                "completion_date_time",
                b"completion_date_time",
                "creation_date_time",
                b"creation_date_time",
                "estimated_completion_ratio",
                b"estimated_completion_ratio",
                "executed_operation_count",
                b"executed_operation_count",
                "operation_count",
                b"operation_count",
            ],
        ) -> None: ...
    type___BatchJobMetadata = BatchJobMetadata

    resource_name: typing___Text = ...
    status: google___ads___googleads___v4___enums___batch_job_status_pb2___BatchJobStatusEnum.BatchJobStatusValue = ...
    @property
    def id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def next_add_sequence_token(
        self,
    ) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def metadata(self) -> type___BatchJob.BatchJobMetadata: ...
    @property
    def long_running_operation(
        self,
    ) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        id: typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        next_add_sequence_token: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        metadata: typing___Optional[type___BatchJob.BatchJobMetadata] = None,
        status: typing___Optional[
            google___ads___googleads___v4___enums___batch_job_status_pb2___BatchJobStatusEnum.BatchJobStatusValue
        ] = None,
        long_running_operation: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "id",
            b"id",
            "long_running_operation",
            b"long_running_operation",
            "metadata",
            b"metadata",
            "next_add_sequence_token",
            b"next_add_sequence_token",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "id",
            b"id",
            "long_running_operation",
            b"long_running_operation",
            "metadata",
            b"metadata",
            "next_add_sequence_token",
            b"next_add_sequence_token",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
        ],
    ) -> None: ...

type___BatchJob = BatchJob



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class CustomerManagerLinkErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    CustomerManagerLinkErrorValue = typing___NewType(
        "CustomerManagerLinkErrorValue", builtin___int
    )
    type___CustomerManagerLinkErrorValue = CustomerManagerLinkErrorValue
    CustomerManagerLinkError: _CustomerManagerLinkError
    class _CustomerManagerLinkError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            CustomerManagerLinkErrorEnum.CustomerManagerLinkErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            CustomerManagerLinkErrorEnum.CustomerManagerLinkErrorValue, 0
        )
        UNKNOWN = typing___cast(
            CustomerManagerLinkErrorEnum.CustomerManagerLinkErrorValue, 1
        )
        NO_PENDING_INVITE = typing___cast(
            CustomerManagerLinkErrorEnum.CustomerManagerLinkErrorValue, 2
        )
        SAME_CLIENT_MORE_THAN_ONCE_PER_CALL = typing___cast(
            CustomerManagerLinkErrorEnum.CustomerManagerLinkErrorValue, 3
        )
        MANAGER_HAS_MAX_NUMBER_OF_LINKED_ACCOUNTS = typing___cast(
            CustomerManagerLinkErrorEnum.CustomerManagerLinkErrorValue, 4
        )
        CANNOT_UNLINK_ACCOUNT_WITHOUT_ACTIVE_USER = typing___cast(
            CustomerManagerLinkErrorEnum.CustomerManagerLinkErrorValue, 5
        )
        CANNOT_REMOVE_LAST_CLIENT_ACCOUNT_OWNER = typing___cast(
            CustomerManagerLinkErrorEnum.CustomerManagerLinkErrorValue, 6
        )
        CANNOT_CHANGE_ROLE_BY_NON_ACCOUNT_OWNER = typing___cast(
            CustomerManagerLinkErrorEnum.CustomerManagerLinkErrorValue, 7
        )
        CANNOT_CHANGE_ROLE_FOR_NON_ACTIVE_LINK_ACCOUNT = typing___cast(
            CustomerManagerLinkErrorEnum.CustomerManagerLinkErrorValue, 8
        )
        DUPLICATE_CHILD_FOUND = typing___cast(
            CustomerManagerLinkErrorEnum.CustomerManagerLinkErrorValue, 9
        )
        TEST_ACCOUNT_LINKS_TOO_MANY_CHILD_ACCOUNTS = typing___cast(
            CustomerManagerLinkErrorEnum.CustomerManagerLinkErrorValue, 10
        )
    UNSPECIFIED = typing___cast(
        CustomerManagerLinkErrorEnum.CustomerManagerLinkErrorValue, 0
    )
    UNKNOWN = typing___cast(
        CustomerManagerLinkErrorEnum.CustomerManagerLinkErrorValue, 1
    )
    NO_PENDING_INVITE = typing___cast(
        CustomerManagerLinkErrorEnum.CustomerManagerLinkErrorValue, 2
    )
    SAME_CLIENT_MORE_THAN_ONCE_PER_CALL = typing___cast(
        CustomerManagerLinkErrorEnum.CustomerManagerLinkErrorValue, 3
    )
    MANAGER_HAS_MAX_NUMBER_OF_LINKED_ACCOUNTS = typing___cast(
        CustomerManagerLinkErrorEnum.CustomerManagerLinkErrorValue, 4
    )
    CANNOT_UNLINK_ACCOUNT_WITHOUT_ACTIVE_USER = typing___cast(
        CustomerManagerLinkErrorEnum.CustomerManagerLinkErrorValue, 5
    )
    CANNOT_REMOVE_LAST_CLIENT_ACCOUNT_OWNER = typing___cast(
        CustomerManagerLinkErrorEnum.CustomerManagerLinkErrorValue, 6
    )
    CANNOT_CHANGE_ROLE_BY_NON_ACCOUNT_OWNER = typing___cast(
        CustomerManagerLinkErrorEnum.CustomerManagerLinkErrorValue, 7
    )
    CANNOT_CHANGE_ROLE_FOR_NON_ACTIVE_LINK_ACCOUNT = typing___cast(
        CustomerManagerLinkErrorEnum.CustomerManagerLinkErrorValue, 8
    )
    DUPLICATE_CHILD_FOUND = typing___cast(
        CustomerManagerLinkErrorEnum.CustomerManagerLinkErrorValue, 9
    )
    TEST_ACCOUNT_LINKS_TOO_MANY_CHILD_ACCOUNTS = typing___cast(
        CustomerManagerLinkErrorEnum.CustomerManagerLinkErrorValue, 10
    )
    type___CustomerManagerLinkError = CustomerManagerLinkError
    def __init__(self,) -> None: ...

type___CustomerManagerLinkErrorEnum = CustomerManagerLinkErrorEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class ResourceCountLimitExceededErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ResourceCountLimitExceededErrorValue = typing___NewType(
        "ResourceCountLimitExceededErrorValue", builtin___int
    )
    type___ResourceCountLimitExceededErrorValue = ResourceCountLimitExceededErrorValue
    ResourceCountLimitExceededError: _ResourceCountLimitExceededError
    class _ResourceCountLimitExceededError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededErrorValue, 0
        )
        UNKNOWN = typing___cast(
            ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededErrorValue, 1
        )
        ACCOUNT_LIMIT = typing___cast(
            ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededErrorValue, 2
        )
        CAMPAIGN_LIMIT = typing___cast(
            ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededErrorValue, 3
        )
        ADGROUP_LIMIT = typing___cast(
            ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededErrorValue, 4
        )
        AD_GROUP_AD_LIMIT = typing___cast(
            ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededErrorValue, 5
        )
        AD_GROUP_CRITERION_LIMIT = typing___cast(
            ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededErrorValue, 6
        )
        SHARED_SET_LIMIT = typing___cast(
            ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededErrorValue, 7
        )
        MATCHING_FUNCTION_LIMIT = typing___cast(
            ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededErrorValue, 8
        )
        RESPONSE_ROW_LIMIT_EXCEEDED = typing___cast(
            ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededErrorValue, 9
        )
        RESOURCE_LIMIT = typing___cast(
            ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededErrorValue, 10
        )
    UNSPECIFIED = typing___cast(
        ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededErrorValue, 0
    )
    UNKNOWN = typing___cast(
        ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededErrorValue, 1
    )
    ACCOUNT_LIMIT = typing___cast(
        ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededErrorValue, 2
    )
    CAMPAIGN_LIMIT = typing___cast(
        ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededErrorValue, 3
    )
    ADGROUP_LIMIT = typing___cast(
        ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededErrorValue, 4
    )
    AD_GROUP_AD_LIMIT = typing___cast(
        ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededErrorValue, 5
    )
    AD_GROUP_CRITERION_LIMIT = typing___cast(
        ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededErrorValue, 6
    )
    SHARED_SET_LIMIT = typing___cast(
        ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededErrorValue, 7
    )
    MATCHING_FUNCTION_LIMIT = typing___cast(
        ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededErrorValue, 8
    )
    RESPONSE_ROW_LIMIT_EXCEEDED = typing___cast(
        ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededErrorValue, 9
    )
    RESOURCE_LIMIT = typing___cast(
        ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededErrorValue, 10
    )
    type___ResourceCountLimitExceededError = ResourceCountLimitExceededError
    def __init__(self,) -> None: ...

type___ResourceCountLimitExceededErrorEnum = ResourceCountLimitExceededErrorEnum



from typing import Any

class MobileDeviceConstantServiceStub:
    GetMobileDeviceConstant: Any = ...
    def __init__(self, channel: Any) -> None: ...

class MobileDeviceConstantServiceServicer:
    def GetMobileDeviceConstant(self, request: Any, context: Any) -> None: ...

def add_MobileDeviceConstantServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class VanityPharmaDisplayUrlModeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    VanityPharmaDisplayUrlModeValue = typing___NewType(
        "VanityPharmaDisplayUrlModeValue", builtin___int
    )
    type___VanityPharmaDisplayUrlModeValue = VanityPharmaDisplayUrlModeValue
    VanityPharmaDisplayUrlMode: _VanityPharmaDisplayUrlMode
    class _VanityPharmaDisplayUrlMode(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            VanityPharmaDisplayUrlModeEnum.VanityPharmaDisplayUrlModeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            VanityPharmaDisplayUrlModeEnum.VanityPharmaDisplayUrlModeValue, 0
        )
        UNKNOWN = typing___cast(
            VanityPharmaDisplayUrlModeEnum.VanityPharmaDisplayUrlModeValue, 1
        )
        MANUFACTURER_WEBSITE_URL = typing___cast(
            VanityPharmaDisplayUrlModeEnum.VanityPharmaDisplayUrlModeValue, 2
        )
        WEBSITE_DESCRIPTION = typing___cast(
            VanityPharmaDisplayUrlModeEnum.VanityPharmaDisplayUrlModeValue, 3
        )
    UNSPECIFIED = typing___cast(
        VanityPharmaDisplayUrlModeEnum.VanityPharmaDisplayUrlModeValue, 0
    )
    UNKNOWN = typing___cast(
        VanityPharmaDisplayUrlModeEnum.VanityPharmaDisplayUrlModeValue, 1
    )
    MANUFACTURER_WEBSITE_URL = typing___cast(
        VanityPharmaDisplayUrlModeEnum.VanityPharmaDisplayUrlModeValue, 2
    )
    WEBSITE_DESCRIPTION = typing___cast(
        VanityPharmaDisplayUrlModeEnum.VanityPharmaDisplayUrlModeValue, 3
    )
    type___VanityPharmaDisplayUrlMode = VanityPharmaDisplayUrlMode
    def __init__(self,) -> None: ...

type___VanityPharmaDisplayUrlModeEnum = VanityPharmaDisplayUrlModeEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class FieldErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    FieldErrorValue = typing___NewType("FieldErrorValue", builtin___int)
    type___FieldErrorValue = FieldErrorValue
    FieldError: _FieldError
    class _FieldError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            FieldErrorEnum.FieldErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(FieldErrorEnum.FieldErrorValue, 0)
        UNKNOWN = typing___cast(FieldErrorEnum.FieldErrorValue, 1)
        REQUIRED = typing___cast(FieldErrorEnum.FieldErrorValue, 2)
        IMMUTABLE_FIELD = typing___cast(FieldErrorEnum.FieldErrorValue, 3)
        INVALID_VALUE = typing___cast(FieldErrorEnum.FieldErrorValue, 4)
        VALUE_MUST_BE_UNSET = typing___cast(FieldErrorEnum.FieldErrorValue, 5)
        REQUIRED_NONEMPTY_LIST = typing___cast(FieldErrorEnum.FieldErrorValue, 6)
        FIELD_CANNOT_BE_CLEARED = typing___cast(FieldErrorEnum.FieldErrorValue, 7)
        BLACKLISTED_VALUE = typing___cast(FieldErrorEnum.FieldErrorValue, 8)
    UNSPECIFIED = typing___cast(FieldErrorEnum.FieldErrorValue, 0)
    UNKNOWN = typing___cast(FieldErrorEnum.FieldErrorValue, 1)
    REQUIRED = typing___cast(FieldErrorEnum.FieldErrorValue, 2)
    IMMUTABLE_FIELD = typing___cast(FieldErrorEnum.FieldErrorValue, 3)
    INVALID_VALUE = typing___cast(FieldErrorEnum.FieldErrorValue, 4)
    VALUE_MUST_BE_UNSET = typing___cast(FieldErrorEnum.FieldErrorValue, 5)
    REQUIRED_NONEMPTY_LIST = typing___cast(FieldErrorEnum.FieldErrorValue, 6)
    FIELD_CANNOT_BE_CLEARED = typing___cast(FieldErrorEnum.FieldErrorValue, 7)
    BLACKLISTED_VALUE = typing___cast(FieldErrorEnum.FieldErrorValue, 8)
    type___FieldError = FieldError
    def __init__(self,) -> None: ...

type___FieldErrorEnum = FieldErrorEnum



from typing import Any

class ChangeStatusServiceStub:
    GetChangeStatus: Any = ...
    def __init__(self, channel: Any) -> None: ...

class ChangeStatusServiceServicer:
    def GetChangeStatus(self, request: Any, context: Any) -> None: ...

def add_ChangeStatusServiceServicer_to_server(servicer: Any, server: Any) -> None: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class ChangeStatusErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ChangeStatusErrorValue = typing___NewType("ChangeStatusErrorValue", builtin___int)
    type___ChangeStatusErrorValue = ChangeStatusErrorValue
    ChangeStatusError: _ChangeStatusError
    class _ChangeStatusError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            ChangeStatusErrorEnum.ChangeStatusErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(ChangeStatusErrorEnum.ChangeStatusErrorValue, 0)
        UNKNOWN = typing___cast(ChangeStatusErrorEnum.ChangeStatusErrorValue, 1)
        START_DATE_TOO_OLD = typing___cast(
            ChangeStatusErrorEnum.ChangeStatusErrorValue, 3
        )
        CHANGE_DATE_RANGE_INFINITE = typing___cast(
            ChangeStatusErrorEnum.ChangeStatusErrorValue, 4
        )
        CHANGE_DATE_RANGE_NEGATIVE = typing___cast(
            ChangeStatusErrorEnum.ChangeStatusErrorValue, 5
        )
        LIMIT_NOT_SPECIFIED = typing___cast(
            ChangeStatusErrorEnum.ChangeStatusErrorValue, 6
        )
        INVALID_LIMIT_CLAUSE = typing___cast(
            ChangeStatusErrorEnum.ChangeStatusErrorValue, 7
        )
    UNSPECIFIED = typing___cast(ChangeStatusErrorEnum.ChangeStatusErrorValue, 0)
    UNKNOWN = typing___cast(ChangeStatusErrorEnum.ChangeStatusErrorValue, 1)
    START_DATE_TOO_OLD = typing___cast(ChangeStatusErrorEnum.ChangeStatusErrorValue, 3)
    CHANGE_DATE_RANGE_INFINITE = typing___cast(
        ChangeStatusErrorEnum.ChangeStatusErrorValue, 4
    )
    CHANGE_DATE_RANGE_NEGATIVE = typing___cast(
        ChangeStatusErrorEnum.ChangeStatusErrorValue, 5
    )
    LIMIT_NOT_SPECIFIED = typing___cast(ChangeStatusErrorEnum.ChangeStatusErrorValue, 6)
    INVALID_LIMIT_CLAUSE = typing___cast(
        ChangeStatusErrorEnum.ChangeStatusErrorValue, 7
    )
    type___ChangeStatusError = ChangeStatusError
    def __init__(self,) -> None: ...

type___ChangeStatusErrorEnum = ChangeStatusErrorEnum



from typing import Any

class SharedCriterionServiceStub:
    GetSharedCriterion: Any = ...
    MutateSharedCriteria: Any = ...
    def __init__(self, channel: Any) -> None: ...

class SharedCriterionServiceServicer:
    def GetSharedCriterion(self, request: Any, context: Any) -> None: ...
    def MutateSharedCriteria(self, request: Any, context: Any) -> None: ...

def add_SharedCriterionServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class PriceExtensionPriceUnitEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    PriceExtensionPriceUnitValue = typing___NewType(
        "PriceExtensionPriceUnitValue", builtin___int
    )
    type___PriceExtensionPriceUnitValue = PriceExtensionPriceUnitValue
    PriceExtensionPriceUnit: _PriceExtensionPriceUnit
    class _PriceExtensionPriceUnit(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            PriceExtensionPriceUnitEnum.PriceExtensionPriceUnitValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            PriceExtensionPriceUnitEnum.PriceExtensionPriceUnitValue, 0
        )
        UNKNOWN = typing___cast(
            PriceExtensionPriceUnitEnum.PriceExtensionPriceUnitValue, 1
        )
        PER_HOUR = typing___cast(
            PriceExtensionPriceUnitEnum.PriceExtensionPriceUnitValue, 2
        )
        PER_DAY = typing___cast(
            PriceExtensionPriceUnitEnum.PriceExtensionPriceUnitValue, 3
        )
        PER_WEEK = typing___cast(
            PriceExtensionPriceUnitEnum.PriceExtensionPriceUnitValue, 4
        )
        PER_MONTH = typing___cast(
            PriceExtensionPriceUnitEnum.PriceExtensionPriceUnitValue, 5
        )
        PER_YEAR = typing___cast(
            PriceExtensionPriceUnitEnum.PriceExtensionPriceUnitValue, 6
        )
        PER_NIGHT = typing___cast(
            PriceExtensionPriceUnitEnum.PriceExtensionPriceUnitValue, 7
        )
    UNSPECIFIED = typing___cast(
        PriceExtensionPriceUnitEnum.PriceExtensionPriceUnitValue, 0
    )
    UNKNOWN = typing___cast(PriceExtensionPriceUnitEnum.PriceExtensionPriceUnitValue, 1)
    PER_HOUR = typing___cast(
        PriceExtensionPriceUnitEnum.PriceExtensionPriceUnitValue, 2
    )
    PER_DAY = typing___cast(PriceExtensionPriceUnitEnum.PriceExtensionPriceUnitValue, 3)
    PER_WEEK = typing___cast(
        PriceExtensionPriceUnitEnum.PriceExtensionPriceUnitValue, 4
    )
    PER_MONTH = typing___cast(
        PriceExtensionPriceUnitEnum.PriceExtensionPriceUnitValue, 5
    )
    PER_YEAR = typing___cast(
        PriceExtensionPriceUnitEnum.PriceExtensionPriceUnitValue, 6
    )
    PER_NIGHT = typing___cast(
        PriceExtensionPriceUnitEnum.PriceExtensionPriceUnitValue, 7
    )
    type___PriceExtensionPriceUnit = PriceExtensionPriceUnit
    def __init__(self,) -> None: ...

type___PriceExtensionPriceUnitEnum = PriceExtensionPriceUnitEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
    overload as typing___overload,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
    RepeatedScalarFieldContainer as google___protobuf___internal___containers___RepeatedScalarFieldContainer,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v5.proto.enums.policy_topic_entry_type_pb2 import (
    PolicyTopicEntryTypeEnum as google___ads___googleads___v5___enums___policy_topic_entry_type_pb2___PolicyTopicEntryTypeEnum,
)
from google.ads.google_ads.v5.proto.enums.policy_topic_evidence_destination_mismatch_url_type_pb2 import (
    PolicyTopicEvidenceDestinationMismatchUrlTypeEnum as google___ads___googleads___v5___enums___policy_topic_evidence_destination_mismatch_url_type_pb2___PolicyTopicEvidenceDestinationMismatchUrlTypeEnum,
)
from google.ads.google_ads.v5.proto.enums.policy_topic_evidence_destination_not_working_device_pb2 import (
    PolicyTopicEvidenceDestinationNotWorkingDeviceEnum as google___ads___googleads___v5___enums___policy_topic_evidence_destination_not_working_device_pb2___PolicyTopicEvidenceDestinationNotWorkingDeviceEnum,
)
from google.ads.google_ads.v5.proto.enums.policy_topic_evidence_destination_not_working_dns_error_type_pb2 import (
    PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum as google___ads___googleads___v5___enums___policy_topic_evidence_destination_not_working_dns_error_type_pb2___PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class PolicyViolationKey(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    policy_name: typing___Text = ...
    violating_text: typing___Text = ...
    def __init__(
        self,
        *,
        policy_name: typing___Optional[typing___Text] = None,
        violating_text: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_policy_name",
            b"_policy_name",
            "_violating_text",
            b"_violating_text",
            "policy_name",
            b"policy_name",
            "violating_text",
            b"violating_text",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_policy_name",
            b"_policy_name",
            "_violating_text",
            b"_violating_text",
            "policy_name",
            b"policy_name",
            "violating_text",
            b"violating_text",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_policy_name", b"_policy_name"]
    ) -> typing_extensions___Literal["policy_name"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_violating_text", b"_violating_text"],
    ) -> typing_extensions___Literal["violating_text"]: ...

type___PolicyViolationKey = PolicyViolationKey

class PolicyValidationParameter(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ignorable_policy_topics: google___protobuf___internal___containers___RepeatedScalarFieldContainer[
        typing___Text
    ] = ...
    @property
    def exempt_policy_violation_keys(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___PolicyViolationKey
    ]: ...
    def __init__(
        self,
        *,
        ignorable_policy_topics: typing___Optional[
            typing___Iterable[typing___Text]
        ] = None,
        exempt_policy_violation_keys: typing___Optional[
            typing___Iterable[type___PolicyViolationKey]
        ] = None,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "exempt_policy_violation_keys",
            b"exempt_policy_violation_keys",
            "ignorable_policy_topics",
            b"ignorable_policy_topics",
        ],
    ) -> None: ...

type___PolicyValidationParameter = PolicyValidationParameter

class PolicyTopicEntry(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    topic: typing___Text = ...
    type: google___ads___googleads___v5___enums___policy_topic_entry_type_pb2___PolicyTopicEntryTypeEnum.PolicyTopicEntryTypeValue = ...
    @property
    def evidences(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___PolicyTopicEvidence
    ]: ...
    @property
    def constraints(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___PolicyTopicConstraint
    ]: ...
    def __init__(
        self,
        *,
        topic: typing___Optional[typing___Text] = None,
        type: typing___Optional[
            google___ads___googleads___v5___enums___policy_topic_entry_type_pb2___PolicyTopicEntryTypeEnum.PolicyTopicEntryTypeValue
        ] = None,
        evidences: typing___Optional[
            typing___Iterable[type___PolicyTopicEvidence]
        ] = None,
        constraints: typing___Optional[
            typing___Iterable[type___PolicyTopicConstraint]
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal["_topic", b"_topic", "topic", b"topic"],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_topic",
            b"_topic",
            "constraints",
            b"constraints",
            "evidences",
            b"evidences",
            "topic",
            b"topic",
            "type",
            b"type",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_topic", b"_topic"]
    ) -> typing_extensions___Literal["topic"]: ...

type___PolicyTopicEntry = PolicyTopicEntry

class PolicyTopicEvidence(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class TextList(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        texts: google___protobuf___internal___containers___RepeatedScalarFieldContainer[
            typing___Text
        ] = ...
        def __init__(
            self, *, texts: typing___Optional[typing___Iterable[typing___Text]] = None,
        ) -> None: ...
        def ClearField(
            self, field_name: typing_extensions___Literal["texts", b"texts"]
        ) -> None: ...
    type___TextList = TextList
    class WebsiteList(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        websites: google___protobuf___internal___containers___RepeatedScalarFieldContainer[
            typing___Text
        ] = ...
        def __init__(
            self,
            *,
            websites: typing___Optional[typing___Iterable[typing___Text]] = None,
        ) -> None: ...
        def ClearField(
            self, field_name: typing_extensions___Literal["websites", b"websites"]
        ) -> None: ...
    type___WebsiteList = WebsiteList
    class DestinationTextList(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        destination_texts: google___protobuf___internal___containers___RepeatedScalarFieldContainer[
            typing___Text
        ] = ...
        def __init__(
            self,
            *,
            destination_texts: typing___Optional[
                typing___Iterable[typing___Text]
            ] = None,
        ) -> None: ...
        def ClearField(
            self,
            field_name: typing_extensions___Literal[
                "destination_texts", b"destination_texts"
            ],
        ) -> None: ...
    type___DestinationTextList = DestinationTextList
    class DestinationMismatch(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        url_types: google___protobuf___internal___containers___RepeatedScalarFieldContainer[
            google___ads___googleads___v5___enums___policy_topic_evidence_destination_mismatch_url_type_pb2___PolicyTopicEvidenceDestinationMismatchUrlTypeEnum.PolicyTopicEvidenceDestinationMismatchUrlTypeValue
        ] = ...
        def __init__(
            self,
            *,
            url_types: typing___Optional[
                typing___Iterable[
                    google___ads___googleads___v5___enums___policy_topic_evidence_destination_mismatch_url_type_pb2___PolicyTopicEvidenceDestinationMismatchUrlTypeEnum.PolicyTopicEvidenceDestinationMismatchUrlTypeValue
                ]
            ] = None,
        ) -> None: ...
        def ClearField(
            self, field_name: typing_extensions___Literal["url_types", b"url_types"]
        ) -> None: ...
    type___DestinationMismatch = DestinationMismatch
    class DestinationNotWorking(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        expanded_url: typing___Text = ...
        device: google___ads___googleads___v5___enums___policy_topic_evidence_destination_not_working_device_pb2___PolicyTopicEvidenceDestinationNotWorkingDeviceEnum.PolicyTopicEvidenceDestinationNotWorkingDeviceValue = ...
        last_checked_date_time: typing___Text = ...
        dns_error_type: google___ads___googleads___v5___enums___policy_topic_evidence_destination_not_working_dns_error_type_pb2___PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum.PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeValue = ...
        http_error_code: builtin___int = ...
        def __init__(
            self,
            *,
            expanded_url: typing___Optional[typing___Text] = None,
            device: typing___Optional[
                google___ads___googleads___v5___enums___policy_topic_evidence_destination_not_working_device_pb2___PolicyTopicEvidenceDestinationNotWorkingDeviceEnum.PolicyTopicEvidenceDestinationNotWorkingDeviceValue
            ] = None,
            last_checked_date_time: typing___Optional[typing___Text] = None,
            dns_error_type: typing___Optional[
                google___ads___googleads___v5___enums___policy_topic_evidence_destination_not_working_dns_error_type_pb2___PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum.PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeValue
            ] = None,
            http_error_code: typing___Optional[builtin___int] = None,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions___Literal[
                "_expanded_url",
                b"_expanded_url",
                "_last_checked_date_time",
                b"_last_checked_date_time",
                "dns_error_type",
                b"dns_error_type",
                "expanded_url",
                b"expanded_url",
                "http_error_code",
                b"http_error_code",
                "last_checked_date_time",
                b"last_checked_date_time",
                "reason",
                b"reason",
            ],
        ) -> builtin___bool: ...
        def ClearField(
            self,
            field_name: typing_extensions___Literal[
                "_expanded_url",
                b"_expanded_url",
                "_last_checked_date_time",
                b"_last_checked_date_time",
                "device",
                b"device",
                "dns_error_type",
                b"dns_error_type",
                "expanded_url",
                b"expanded_url",
                "http_error_code",
                b"http_error_code",
                "last_checked_date_time",
                b"last_checked_date_time",
                "reason",
                b"reason",
            ],
        ) -> None: ...
        @typing___overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions___Literal["_expanded_url", b"_expanded_url"],
        ) -> typing_extensions___Literal["expanded_url"]: ...
        @typing___overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions___Literal[
                "_last_checked_date_time", b"_last_checked_date_time"
            ],
        ) -> typing_extensions___Literal["last_checked_date_time"]: ...
        @typing___overload
        def WhichOneof(
            self, oneof_group: typing_extensions___Literal["reason", b"reason"]
        ) -> typing_extensions___Literal["dns_error_type", "http_error_code"]: ...
    type___DestinationNotWorking = DestinationNotWorking

    language_code: typing___Text = ...
    @property
    def website_list(self) -> type___PolicyTopicEvidence.WebsiteList: ...
    @property
    def text_list(self) -> type___PolicyTopicEvidence.TextList: ...
    @property
    def destination_text_list(
        self,
    ) -> type___PolicyTopicEvidence.DestinationTextList: ...
    @property
    def destination_mismatch(
        self,
    ) -> type___PolicyTopicEvidence.DestinationMismatch: ...
    @property
    def destination_not_working(
        self,
    ) -> type___PolicyTopicEvidence.DestinationNotWorking: ...
    def __init__(
        self,
        *,
        website_list: typing___Optional[type___PolicyTopicEvidence.WebsiteList] = None,
        text_list: typing___Optional[type___PolicyTopicEvidence.TextList] = None,
        language_code: typing___Optional[typing___Text] = None,
        destination_text_list: typing___Optional[
            type___PolicyTopicEvidence.DestinationTextList
        ] = None,
        destination_mismatch: typing___Optional[
            type___PolicyTopicEvidence.DestinationMismatch
        ] = None,
        destination_not_working: typing___Optional[
            type___PolicyTopicEvidence.DestinationNotWorking
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "destination_mismatch",
            b"destination_mismatch",
            "destination_not_working",
            b"destination_not_working",
            "destination_text_list",
            b"destination_text_list",
            "language_code",
            b"language_code",
            "text_list",
            b"text_list",
            "value",
            b"value",
            "website_list",
            b"website_list",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "destination_mismatch",
            b"destination_mismatch",
            "destination_not_working",
            b"destination_not_working",
            "destination_text_list",
            b"destination_text_list",
            "language_code",
            b"language_code",
            "text_list",
            b"text_list",
            "value",
            b"value",
            "website_list",
            b"website_list",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["value", b"value"]
    ) -> typing_extensions___Literal[
        "website_list",
        "text_list",
        "language_code",
        "destination_text_list",
        "destination_mismatch",
        "destination_not_working",
    ]: ...

type___PolicyTopicEvidence = PolicyTopicEvidence

class PolicyTopicConstraint(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class CountryConstraintList(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        total_targeted_countries: builtin___int = ...
        @property
        def countries(
            self,
        ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
            type___PolicyTopicConstraint.CountryConstraint
        ]: ...
        def __init__(
            self,
            *,
            total_targeted_countries: typing___Optional[builtin___int] = None,
            countries: typing___Optional[
                typing___Iterable[type___PolicyTopicConstraint.CountryConstraint]
            ] = None,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions___Literal[
                "_total_targeted_countries",
                b"_total_targeted_countries",
                "total_targeted_countries",
                b"total_targeted_countries",
            ],
        ) -> builtin___bool: ...
        def ClearField(
            self,
            field_name: typing_extensions___Literal[
                "_total_targeted_countries",
                b"_total_targeted_countries",
                "countries",
                b"countries",
                "total_targeted_countries",
                b"total_targeted_countries",
            ],
        ) -> None: ...
        def WhichOneof(
            self,
            oneof_group: typing_extensions___Literal[
                "_total_targeted_countries", b"_total_targeted_countries"
            ],
        ) -> typing_extensions___Literal["total_targeted_countries"]: ...
    type___CountryConstraintList = CountryConstraintList
    class ResellerConstraint(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        def __init__(self,) -> None: ...
    type___ResellerConstraint = ResellerConstraint
    class CountryConstraint(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        country_criterion: typing___Text = ...
        def __init__(
            self, *, country_criterion: typing___Optional[typing___Text] = None,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions___Literal[
                "_country_criterion",
                b"_country_criterion",
                "country_criterion",
                b"country_criterion",
            ],
        ) -> builtin___bool: ...
        def ClearField(
            self,
            field_name: typing_extensions___Literal[
                "_country_criterion",
                b"_country_criterion",
                "country_criterion",
                b"country_criterion",
            ],
        ) -> None: ...
        def WhichOneof(
            self,
            oneof_group: typing_extensions___Literal[
                "_country_criterion", b"_country_criterion"
            ],
        ) -> typing_extensions___Literal["country_criterion"]: ...
    type___CountryConstraint = CountryConstraint
    @property
    def country_constraint_list(
        self,
    ) -> type___PolicyTopicConstraint.CountryConstraintList: ...
    @property
    def reseller_constraint(
        self,
    ) -> type___PolicyTopicConstraint.ResellerConstraint: ...
    @property
    def certificate_missing_in_country_list(
        self,
    ) -> type___PolicyTopicConstraint.CountryConstraintList: ...
    @property
    def certificate_domain_mismatch_in_country_list(
        self,
    ) -> type___PolicyTopicConstraint.CountryConstraintList: ...
    def __init__(
        self,
        *,
        country_constraint_list: typing___Optional[
            type___PolicyTopicConstraint.CountryConstraintList
        ] = None,
        reseller_constraint: typing___Optional[
            type___PolicyTopicConstraint.ResellerConstraint
        ] = None,
        certificate_missing_in_country_list: typing___Optional[
            type___PolicyTopicConstraint.CountryConstraintList
        ] = None,
        certificate_domain_mismatch_in_country_list: typing___Optional[
            type___PolicyTopicConstraint.CountryConstraintList
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "certificate_domain_mismatch_in_country_list",
            b"certificate_domain_mismatch_in_country_list",
            "certificate_missing_in_country_list",
            b"certificate_missing_in_country_list",
            "country_constraint_list",
            b"country_constraint_list",
            "reseller_constraint",
            b"reseller_constraint",
            "value",
            b"value",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "certificate_domain_mismatch_in_country_list",
            b"certificate_domain_mismatch_in_country_list",
            "certificate_missing_in_country_list",
            b"certificate_missing_in_country_list",
            "country_constraint_list",
            b"country_constraint_list",
            "reseller_constraint",
            b"reseller_constraint",
            "value",
            b"value",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["value", b"value"]
    ) -> typing_extensions___Literal[
        "country_constraint_list",
        "reseller_constraint",
        "certificate_missing_in_country_list",
        "certificate_domain_mismatch_in_country_list",
    ]: ...

type___PolicyTopicConstraint = PolicyTopicConstraint



# @generated by mypy-protobuf.  Do not edit manually!
import sys

from google.protobuf.descriptor import (
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class MutateJobErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    MutateJobErrorValue = typing___NewType("MutateJobErrorValue", builtin___int)
    type___MutateJobErrorValue = MutateJobErrorValue
    MutateJobError: _MutateJobError
    class _MutateJobError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            MutateJobErrorEnum.MutateJobErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(MutateJobErrorEnum.MutateJobErrorValue, 0)
        UNKNOWN = typing___cast(MutateJobErrorEnum.MutateJobErrorValue, 1)
        CANNOT_MODIFY_JOB_AFTER_JOB_STARTS_RUNNING = typing___cast(
            MutateJobErrorEnum.MutateJobErrorValue, 2
        )
        EMPTY_OPERATIONS = typing___cast(MutateJobErrorEnum.MutateJobErrorValue, 3)
        INVALID_SEQUENCE_TOKEN = typing___cast(
            MutateJobErrorEnum.MutateJobErrorValue, 4
        )
        RESULTS_NOT_READY = typing___cast(MutateJobErrorEnum.MutateJobErrorValue, 5)
        INVALID_PAGE_SIZE = typing___cast(MutateJobErrorEnum.MutateJobErrorValue, 6)
    UNSPECIFIED = typing___cast(MutateJobErrorEnum.MutateJobErrorValue, 0)
    UNKNOWN = typing___cast(MutateJobErrorEnum.MutateJobErrorValue, 1)
    CANNOT_MODIFY_JOB_AFTER_JOB_STARTS_RUNNING = typing___cast(
        MutateJobErrorEnum.MutateJobErrorValue, 2
    )
    EMPTY_OPERATIONS = typing___cast(MutateJobErrorEnum.MutateJobErrorValue, 3)
    INVALID_SEQUENCE_TOKEN = typing___cast(MutateJobErrorEnum.MutateJobErrorValue, 4)
    RESULTS_NOT_READY = typing___cast(MutateJobErrorEnum.MutateJobErrorValue, 5)
    INVALID_PAGE_SIZE = typing___cast(MutateJobErrorEnum.MutateJobErrorValue, 6)
    type___MutateJobError = MutateJobError
    def __init__(self,) -> None: ...

type___MutateJobErrorEnum = MutateJobErrorEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import Optional as typing___Optional, Text as typing___Text

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from google.protobuf.wrappers_pb2 import (
    BoolValue as google___protobuf___wrappers_pb2___BoolValue,
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v5.proto.common.user_lists_pb2 import (
    BasicUserListInfo as google___ads___googleads___v5___common___user_lists_pb2___BasicUserListInfo,
    CrmBasedUserListInfo as google___ads___googleads___v5___common___user_lists_pb2___CrmBasedUserListInfo,
    LogicalUserListInfo as google___ads___googleads___v5___common___user_lists_pb2___LogicalUserListInfo,
    RuleBasedUserListInfo as google___ads___googleads___v5___common___user_lists_pb2___RuleBasedUserListInfo,
    SimilarUserListInfo as google___ads___googleads___v5___common___user_lists_pb2___SimilarUserListInfo,
)
from google.ads.google_ads.v5.proto.enums.access_reason_pb2 import (
    AccessReasonEnum as google___ads___googleads___v5___enums___access_reason_pb2___AccessReasonEnum,
)
from google.ads.google_ads.v5.proto.enums.user_list_access_status_pb2 import (
    UserListAccessStatusEnum as google___ads___googleads___v5___enums___user_list_access_status_pb2___UserListAccessStatusEnum,
)
from google.ads.google_ads.v5.proto.enums.user_list_closing_reason_pb2 import (
    UserListClosingReasonEnum as google___ads___googleads___v5___enums___user_list_closing_reason_pb2___UserListClosingReasonEnum,
)
from google.ads.google_ads.v5.proto.enums.user_list_membership_status_pb2 import (
    UserListMembershipStatusEnum as google___ads___googleads___v5___enums___user_list_membership_status_pb2___UserListMembershipStatusEnum,
)
from google.ads.google_ads.v5.proto.enums.user_list_size_range_pb2 import (
    UserListSizeRangeEnum as google___ads___googleads___v5___enums___user_list_size_range_pb2___UserListSizeRangeEnum,
)
from google.ads.google_ads.v5.proto.enums.user_list_type_pb2 import (
    UserListTypeEnum as google___ads___googleads___v5___enums___user_list_type_pb2___UserListTypeEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class UserList(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    membership_status: google___ads___googleads___v5___enums___user_list_membership_status_pb2___UserListMembershipStatusEnum.UserListMembershipStatusValue = ...
    size_range_for_display: google___ads___googleads___v5___enums___user_list_size_range_pb2___UserListSizeRangeEnum.UserListSizeRangeValue = ...
    size_range_for_search: google___ads___googleads___v5___enums___user_list_size_range_pb2___UserListSizeRangeEnum.UserListSizeRangeValue = ...
    type: google___ads___googleads___v5___enums___user_list_type_pb2___UserListTypeEnum.UserListTypeValue = ...
    closing_reason: google___ads___googleads___v5___enums___user_list_closing_reason_pb2___UserListClosingReasonEnum.UserListClosingReasonValue = ...
    access_reason: google___ads___googleads___v5___enums___access_reason_pb2___AccessReasonEnum.AccessReasonValue = ...
    account_user_list_status: google___ads___googleads___v5___enums___user_list_access_status_pb2___UserListAccessStatusEnum.UserListAccessStatusValue = ...
    @property
    def id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def read_only(self) -> google___protobuf___wrappers_pb2___BoolValue: ...
    @property
    def name(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def description(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def integration_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def membership_life_span(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def size_for_display(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def size_for_search(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def eligible_for_search(self) -> google___protobuf___wrappers_pb2___BoolValue: ...
    @property
    def eligible_for_display(self) -> google___protobuf___wrappers_pb2___BoolValue: ...
    @property
    def crm_based_user_list(
        self,
    ) -> google___ads___googleads___v5___common___user_lists_pb2___CrmBasedUserListInfo: ...
    @property
    def similar_user_list(
        self,
    ) -> google___ads___googleads___v5___common___user_lists_pb2___SimilarUserListInfo: ...
    @property
    def rule_based_user_list(
        self,
    ) -> google___ads___googleads___v5___common___user_lists_pb2___RuleBasedUserListInfo: ...
    @property
    def logical_user_list(
        self,
    ) -> google___ads___googleads___v5___common___user_lists_pb2___LogicalUserListInfo: ...
    @property
    def basic_user_list(
        self,
    ) -> google___ads___googleads___v5___common___user_lists_pb2___BasicUserListInfo: ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        id: typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        read_only: typing___Optional[
            google___protobuf___wrappers_pb2___BoolValue
        ] = None,
        name: typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        description: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        membership_status: typing___Optional[
            google___ads___googleads___v5___enums___user_list_membership_status_pb2___UserListMembershipStatusEnum.UserListMembershipStatusValue
        ] = None,
        integration_code: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        membership_life_span: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        size_for_display: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        size_range_for_display: typing___Optional[
            google___ads___googleads___v5___enums___user_list_size_range_pb2___UserListSizeRangeEnum.UserListSizeRangeValue
        ] = None,
        size_for_search: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        size_range_for_search: typing___Optional[
            google___ads___googleads___v5___enums___user_list_size_range_pb2___UserListSizeRangeEnum.UserListSizeRangeValue
        ] = None,
        type: typing___Optional[
            google___ads___googleads___v5___enums___user_list_type_pb2___UserListTypeEnum.UserListTypeValue
        ] = None,
        closing_reason: typing___Optional[
            google___ads___googleads___v5___enums___user_list_closing_reason_pb2___UserListClosingReasonEnum.UserListClosingReasonValue
        ] = None,
        access_reason: typing___Optional[
            google___ads___googleads___v5___enums___access_reason_pb2___AccessReasonEnum.AccessReasonValue
        ] = None,
        account_user_list_status: typing___Optional[
            google___ads___googleads___v5___enums___user_list_access_status_pb2___UserListAccessStatusEnum.UserListAccessStatusValue
        ] = None,
        eligible_for_search: typing___Optional[
            google___protobuf___wrappers_pb2___BoolValue
        ] = None,
        eligible_for_display: typing___Optional[
            google___protobuf___wrappers_pb2___BoolValue
        ] = None,
        crm_based_user_list: typing___Optional[
            google___ads___googleads___v5___common___user_lists_pb2___CrmBasedUserListInfo
        ] = None,
        similar_user_list: typing___Optional[
            google___ads___googleads___v5___common___user_lists_pb2___SimilarUserListInfo
        ] = None,
        rule_based_user_list: typing___Optional[
            google___ads___googleads___v5___common___user_lists_pb2___RuleBasedUserListInfo
        ] = None,
        logical_user_list: typing___Optional[
            google___ads___googleads___v5___common___user_lists_pb2___LogicalUserListInfo
        ] = None,
        basic_user_list: typing___Optional[
            google___ads___googleads___v5___common___user_lists_pb2___BasicUserListInfo
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "basic_user_list",
            b"basic_user_list",
            "crm_based_user_list",
            b"crm_based_user_list",
            "description",
            b"description",
            "eligible_for_display",
            b"eligible_for_display",
            "eligible_for_search",
            b"eligible_for_search",
            "id",
            b"id",
            "integration_code",
            b"integration_code",
            "logical_user_list",
            b"logical_user_list",
            "membership_life_span",
            b"membership_life_span",
            "name",
            b"name",
            "read_only",
            b"read_only",
            "rule_based_user_list",
            b"rule_based_user_list",
            "similar_user_list",
            b"similar_user_list",
            "size_for_display",
            b"size_for_display",
            "size_for_search",
            b"size_for_search",
            "user_list",
            b"user_list",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "access_reason",
            b"access_reason",
            "account_user_list_status",
            b"account_user_list_status",
            "basic_user_list",
            b"basic_user_list",
            "closing_reason",
            b"closing_reason",
            "crm_based_user_list",
            b"crm_based_user_list",
            "description",
            b"description",
            "eligible_for_display",
            b"eligible_for_display",
            "eligible_for_search",
            b"eligible_for_search",
            "id",
            b"id",
            "integration_code",
            b"integration_code",
            "logical_user_list",
            b"logical_user_list",
            "membership_life_span",
            b"membership_life_span",
            "membership_status",
            b"membership_status",
            "name",
            b"name",
            "read_only",
            b"read_only",
            "resource_name",
            b"resource_name",
            "rule_based_user_list",
            b"rule_based_user_list",
            "similar_user_list",
            b"similar_user_list",
            "size_for_display",
            b"size_for_display",
            "size_for_search",
            b"size_for_search",
            "size_range_for_display",
            b"size_range_for_display",
            "size_range_for_search",
            b"size_range_for_search",
            "type",
            b"type",
            "user_list",
            b"user_list",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["user_list", b"user_list"]
    ) -> typing_extensions___Literal[
        "crm_based_user_list",
        "similar_user_list",
        "rule_based_user_list",
        "logical_user_list",
        "basic_user_list",
    ]: ...

type___UserList = UserList



# Stubs for google.ads.google_ads.v6.proto.services.campaign_draft_service_pb2_grpc (Python 3)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any, Optional

class CampaignDraftServiceStub:
    GetCampaignDraft: Any = ...
    MutateCampaignDrafts: Any = ...
    PromoteCampaignDraft: Any = ...
    ListCampaignDraftAsyncErrors: Any = ...
    def __init__(self, channel: Any) -> None: ...

class CampaignDraftServiceServicer:
    def GetCampaignDraft(self, request: Any, context: Any) -> None: ...
    def MutateCampaignDrafts(self, request: Any, context: Any) -> None: ...
    def PromoteCampaignDraft(self, request: Any, context: Any) -> None: ...
    def ListCampaignDraftAsyncErrors(self, request: Any, context: Any) -> None: ...

def add_CampaignDraftServiceServicer_to_server(servicer: Any, server: Any) -> None: ...

class CampaignDraftService:
    @staticmethod
    def GetCampaignDraft(
        request: Any,
        target: Any,
        options: Any = ...,
        channel_credentials: Optional[Any] = ...,
        call_credentials: Optional[Any] = ...,
        compression: Optional[Any] = ...,
        wait_for_ready: Optional[Any] = ...,
        timeout: Optional[Any] = ...,
        metadata: Optional[Any] = ...,
    ): ...
    @staticmethod
    def MutateCampaignDrafts(
        request: Any,
        target: Any,
        options: Any = ...,
        channel_credentials: Optional[Any] = ...,
        call_credentials: Optional[Any] = ...,
        compression: Optional[Any] = ...,
        wait_for_ready: Optional[Any] = ...,
        timeout: Optional[Any] = ...,
        metadata: Optional[Any] = ...,
    ): ...
    @staticmethod
    def PromoteCampaignDraft(
        request: Any,
        target: Any,
        options: Any = ...,
        channel_credentials: Optional[Any] = ...,
        call_credentials: Optional[Any] = ...,
        compression: Optional[Any] = ...,
        wait_for_ready: Optional[Any] = ...,
        timeout: Optional[Any] = ...,
        metadata: Optional[Any] = ...,
    ): ...
    @staticmethod
    def ListCampaignDraftAsyncErrors(
        request: Any,
        target: Any,
        options: Any = ...,
        channel_credentials: Optional[Any] = ...,
        call_credentials: Optional[Any] = ...,
        compression: Optional[Any] = ...,
        wait_for_ready: Optional[Any] = ...,
        timeout: Optional[Any] = ...,
        metadata: Optional[Any] = ...,
    ): ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import Optional as typing___Optional, Text as typing___Text

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v6.proto.enums.placeholder_type_pb2 import (
    PlaceholderTypeEnum as google___ads___googleads___v6___enums___placeholder_type_pb2___PlaceholderTypeEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class FeedPlaceholderView(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    placeholder_type: google___ads___googleads___v6___enums___placeholder_type_pb2___PlaceholderTypeEnum.PlaceholderTypeValue = ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        placeholder_type: typing___Optional[
            google___ads___googleads___v6___enums___placeholder_type_pb2___PlaceholderTypeEnum.PlaceholderTypeValue
        ] = None,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "placeholder_type", b"placeholder_type", "resource_name", b"resource_name"
        ],
    ) -> None: ...

type___FeedPlaceholderView = FeedPlaceholderView



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class ProductCustomAttributeIndexEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ProductCustomAttributeIndexValue = typing___NewType(
        "ProductCustomAttributeIndexValue", builtin___int
    )
    type___ProductCustomAttributeIndexValue = ProductCustomAttributeIndexValue
    ProductCustomAttributeIndex: _ProductCustomAttributeIndex
    class _ProductCustomAttributeIndex(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            ProductCustomAttributeIndexEnum.ProductCustomAttributeIndexValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            ProductCustomAttributeIndexEnum.ProductCustomAttributeIndexValue, 0
        )
        UNKNOWN = typing___cast(
            ProductCustomAttributeIndexEnum.ProductCustomAttributeIndexValue, 1
        )
        INDEX0 = typing___cast(
            ProductCustomAttributeIndexEnum.ProductCustomAttributeIndexValue, 7
        )
        INDEX1 = typing___cast(
            ProductCustomAttributeIndexEnum.ProductCustomAttributeIndexValue, 8
        )
        INDEX2 = typing___cast(
            ProductCustomAttributeIndexEnum.ProductCustomAttributeIndexValue, 9
        )
        INDEX3 = typing___cast(
            ProductCustomAttributeIndexEnum.ProductCustomAttributeIndexValue, 10
        )
        INDEX4 = typing___cast(
            ProductCustomAttributeIndexEnum.ProductCustomAttributeIndexValue, 11
        )
    UNSPECIFIED = typing___cast(
        ProductCustomAttributeIndexEnum.ProductCustomAttributeIndexValue, 0
    )
    UNKNOWN = typing___cast(
        ProductCustomAttributeIndexEnum.ProductCustomAttributeIndexValue, 1
    )
    INDEX0 = typing___cast(
        ProductCustomAttributeIndexEnum.ProductCustomAttributeIndexValue, 7
    )
    INDEX1 = typing___cast(
        ProductCustomAttributeIndexEnum.ProductCustomAttributeIndexValue, 8
    )
    INDEX2 = typing___cast(
        ProductCustomAttributeIndexEnum.ProductCustomAttributeIndexValue, 9
    )
    INDEX3 = typing___cast(
        ProductCustomAttributeIndexEnum.ProductCustomAttributeIndexValue, 10
    )
    INDEX4 = typing___cast(
        ProductCustomAttributeIndexEnum.ProductCustomAttributeIndexValue, 11
    )
    type___ProductCustomAttributeIndex = ProductCustomAttributeIndex
    def __init__(self,) -> None: ...

type___ProductCustomAttributeIndexEnum = ProductCustomAttributeIndexEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
    overload as typing___overload,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v6.proto.common.simulation_pb2 import (
    CpcBidSimulationPointList as google___ads___googleads___v6___common___simulation_pb2___CpcBidSimulationPointList,
    PercentCpcBidSimulationPointList as google___ads___googleads___v6___common___simulation_pb2___PercentCpcBidSimulationPointList,
)
from google.ads.google_ads.v6.proto.enums.simulation_modification_method_pb2 import (
    SimulationModificationMethodEnum as google___ads___googleads___v6___enums___simulation_modification_method_pb2___SimulationModificationMethodEnum,
)
from google.ads.google_ads.v6.proto.enums.simulation_type_pb2 import (
    SimulationTypeEnum as google___ads___googleads___v6___enums___simulation_type_pb2___SimulationTypeEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class AdGroupCriterionSimulation(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    ad_group_id: builtin___int = ...
    criterion_id: builtin___int = ...
    type: google___ads___googleads___v6___enums___simulation_type_pb2___SimulationTypeEnum.SimulationTypeValue = ...
    modification_method: google___ads___googleads___v6___enums___simulation_modification_method_pb2___SimulationModificationMethodEnum.SimulationModificationMethodValue = ...
    start_date: typing___Text = ...
    end_date: typing___Text = ...
    @property
    def cpc_bid_point_list(
        self,
    ) -> google___ads___googleads___v6___common___simulation_pb2___CpcBidSimulationPointList: ...
    @property
    def percent_cpc_bid_point_list(
        self,
    ) -> google___ads___googleads___v6___common___simulation_pb2___PercentCpcBidSimulationPointList: ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        ad_group_id: typing___Optional[builtin___int] = None,
        criterion_id: typing___Optional[builtin___int] = None,
        type: typing___Optional[
            google___ads___googleads___v6___enums___simulation_type_pb2___SimulationTypeEnum.SimulationTypeValue
        ] = None,
        modification_method: typing___Optional[
            google___ads___googleads___v6___enums___simulation_modification_method_pb2___SimulationModificationMethodEnum.SimulationModificationMethodValue
        ] = None,
        start_date: typing___Optional[typing___Text] = None,
        end_date: typing___Optional[typing___Text] = None,
        cpc_bid_point_list: typing___Optional[
            google___ads___googleads___v6___common___simulation_pb2___CpcBidSimulationPointList
        ] = None,
        percent_cpc_bid_point_list: typing___Optional[
            google___ads___googleads___v6___common___simulation_pb2___PercentCpcBidSimulationPointList
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_ad_group_id",
            b"_ad_group_id",
            "_criterion_id",
            b"_criterion_id",
            "_end_date",
            b"_end_date",
            "_start_date",
            b"_start_date",
            "ad_group_id",
            b"ad_group_id",
            "cpc_bid_point_list",
            b"cpc_bid_point_list",
            "criterion_id",
            b"criterion_id",
            "end_date",
            b"end_date",
            "percent_cpc_bid_point_list",
            b"percent_cpc_bid_point_list",
            "point_list",
            b"point_list",
            "start_date",
            b"start_date",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_ad_group_id",
            b"_ad_group_id",
            "_criterion_id",
            b"_criterion_id",
            "_end_date",
            b"_end_date",
            "_start_date",
            b"_start_date",
            "ad_group_id",
            b"ad_group_id",
            "cpc_bid_point_list",
            b"cpc_bid_point_list",
            "criterion_id",
            b"criterion_id",
            "end_date",
            b"end_date",
            "modification_method",
            b"modification_method",
            "percent_cpc_bid_point_list",
            b"percent_cpc_bid_point_list",
            "point_list",
            b"point_list",
            "resource_name",
            b"resource_name",
            "start_date",
            b"start_date",
            "type",
            b"type",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_ad_group_id", b"_ad_group_id"]
    ) -> typing_extensions___Literal["ad_group_id"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_criterion_id", b"_criterion_id"],
    ) -> typing_extensions___Literal["criterion_id"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_end_date", b"_end_date"]
    ) -> typing_extensions___Literal["end_date"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_start_date", b"_start_date"]
    ) -> typing_extensions___Literal["start_date"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["point_list", b"point_list"]
    ) -> typing_extensions___Literal[
        "cpc_bid_point_list", "percent_cpc_bid_point_list"
    ]: ...

type___AdGroupCriterionSimulation = AdGroupCriterionSimulation



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
    overload as typing___overload,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v6.proto.enums.ad_customizer_placeholder_field_pb2 import (
    AdCustomizerPlaceholderFieldEnum as google___ads___googleads___v6___enums___ad_customizer_placeholder_field_pb2___AdCustomizerPlaceholderFieldEnum,
)
from google.ads.google_ads.v6.proto.enums.affiliate_location_placeholder_field_pb2 import (
    AffiliateLocationPlaceholderFieldEnum as google___ads___googleads___v6___enums___affiliate_location_placeholder_field_pb2___AffiliateLocationPlaceholderFieldEnum,
)
from google.ads.google_ads.v6.proto.enums.app_placeholder_field_pb2 import (
    AppPlaceholderFieldEnum as google___ads___googleads___v6___enums___app_placeholder_field_pb2___AppPlaceholderFieldEnum,
)
from google.ads.google_ads.v6.proto.enums.call_placeholder_field_pb2 import (
    CallPlaceholderFieldEnum as google___ads___googleads___v6___enums___call_placeholder_field_pb2___CallPlaceholderFieldEnum,
)
from google.ads.google_ads.v6.proto.enums.callout_placeholder_field_pb2 import (
    CalloutPlaceholderFieldEnum as google___ads___googleads___v6___enums___callout_placeholder_field_pb2___CalloutPlaceholderFieldEnum,
)
from google.ads.google_ads.v6.proto.enums.custom_placeholder_field_pb2 import (
    CustomPlaceholderFieldEnum as google___ads___googleads___v6___enums___custom_placeholder_field_pb2___CustomPlaceholderFieldEnum,
)
from google.ads.google_ads.v6.proto.enums.dsa_page_feed_criterion_field_pb2 import (
    DsaPageFeedCriterionFieldEnum as google___ads___googleads___v6___enums___dsa_page_feed_criterion_field_pb2___DsaPageFeedCriterionFieldEnum,
)
from google.ads.google_ads.v6.proto.enums.education_placeholder_field_pb2 import (
    EducationPlaceholderFieldEnum as google___ads___googleads___v6___enums___education_placeholder_field_pb2___EducationPlaceholderFieldEnum,
)
from google.ads.google_ads.v6.proto.enums.feed_mapping_criterion_type_pb2 import (
    FeedMappingCriterionTypeEnum as google___ads___googleads___v6___enums___feed_mapping_criterion_type_pb2___FeedMappingCriterionTypeEnum,
)
from google.ads.google_ads.v6.proto.enums.feed_mapping_status_pb2 import (
    FeedMappingStatusEnum as google___ads___googleads___v6___enums___feed_mapping_status_pb2___FeedMappingStatusEnum,
)
from google.ads.google_ads.v6.proto.enums.flight_placeholder_field_pb2 import (
    FlightPlaceholderFieldEnum as google___ads___googleads___v6___enums___flight_placeholder_field_pb2___FlightPlaceholderFieldEnum,
)
from google.ads.google_ads.v6.proto.enums.hotel_placeholder_field_pb2 import (
    HotelPlaceholderFieldEnum as google___ads___googleads___v6___enums___hotel_placeholder_field_pb2___HotelPlaceholderFieldEnum,
)
from google.ads.google_ads.v6.proto.enums.job_placeholder_field_pb2 import (
    JobPlaceholderFieldEnum as google___ads___googleads___v6___enums___job_placeholder_field_pb2___JobPlaceholderFieldEnum,
)
from google.ads.google_ads.v6.proto.enums.local_placeholder_field_pb2 import (
    LocalPlaceholderFieldEnum as google___ads___googleads___v6___enums___local_placeholder_field_pb2___LocalPlaceholderFieldEnum,
)
from google.ads.google_ads.v6.proto.enums.location_extension_targeting_criterion_field_pb2 import (
    LocationExtensionTargetingCriterionFieldEnum as google___ads___googleads___v6___enums___location_extension_targeting_criterion_field_pb2___LocationExtensionTargetingCriterionFieldEnum,
)
from google.ads.google_ads.v6.proto.enums.location_placeholder_field_pb2 import (
    LocationPlaceholderFieldEnum as google___ads___googleads___v6___enums___location_placeholder_field_pb2___LocationPlaceholderFieldEnum,
)
from google.ads.google_ads.v6.proto.enums.message_placeholder_field_pb2 import (
    MessagePlaceholderFieldEnum as google___ads___googleads___v6___enums___message_placeholder_field_pb2___MessagePlaceholderFieldEnum,
)
from google.ads.google_ads.v6.proto.enums.placeholder_type_pb2 import (
    PlaceholderTypeEnum as google___ads___googleads___v6___enums___placeholder_type_pb2___PlaceholderTypeEnum,
)
from google.ads.google_ads.v6.proto.enums.price_placeholder_field_pb2 import (
    PricePlaceholderFieldEnum as google___ads___googleads___v6___enums___price_placeholder_field_pb2___PricePlaceholderFieldEnum,
)
from google.ads.google_ads.v6.proto.enums.promotion_placeholder_field_pb2 import (
    PromotionPlaceholderFieldEnum as google___ads___googleads___v6___enums___promotion_placeholder_field_pb2___PromotionPlaceholderFieldEnum,
)
from google.ads.google_ads.v6.proto.enums.real_estate_placeholder_field_pb2 import (
    RealEstatePlaceholderFieldEnum as google___ads___googleads___v6___enums___real_estate_placeholder_field_pb2___RealEstatePlaceholderFieldEnum,
)
from google.ads.google_ads.v6.proto.enums.sitelink_placeholder_field_pb2 import (
    SitelinkPlaceholderFieldEnum as google___ads___googleads___v6___enums___sitelink_placeholder_field_pb2___SitelinkPlaceholderFieldEnum,
)
from google.ads.google_ads.v6.proto.enums.structured_snippet_placeholder_field_pb2 import (
    StructuredSnippetPlaceholderFieldEnum as google___ads___googleads___v6___enums___structured_snippet_placeholder_field_pb2___StructuredSnippetPlaceholderFieldEnum,
)
from google.ads.google_ads.v6.proto.enums.travel_placeholder_field_pb2 import (
    TravelPlaceholderFieldEnum as google___ads___googleads___v6___enums___travel_placeholder_field_pb2___TravelPlaceholderFieldEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class FeedMapping(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    feed: typing___Text = ...
    status: google___ads___googleads___v6___enums___feed_mapping_status_pb2___FeedMappingStatusEnum.FeedMappingStatusValue = ...
    placeholder_type: google___ads___googleads___v6___enums___placeholder_type_pb2___PlaceholderTypeEnum.PlaceholderTypeValue = ...
    criterion_type: google___ads___googleads___v6___enums___feed_mapping_criterion_type_pb2___FeedMappingCriterionTypeEnum.FeedMappingCriterionTypeValue = ...
    @property
    def attribute_field_mappings(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___AttributeFieldMapping
    ]: ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        feed: typing___Optional[typing___Text] = None,
        attribute_field_mappings: typing___Optional[
            typing___Iterable[type___AttributeFieldMapping]
        ] = None,
        status: typing___Optional[
            google___ads___googleads___v6___enums___feed_mapping_status_pb2___FeedMappingStatusEnum.FeedMappingStatusValue
        ] = None,
        placeholder_type: typing___Optional[
            google___ads___googleads___v6___enums___placeholder_type_pb2___PlaceholderTypeEnum.PlaceholderTypeValue
        ] = None,
        criterion_type: typing___Optional[
            google___ads___googleads___v6___enums___feed_mapping_criterion_type_pb2___FeedMappingCriterionTypeEnum.FeedMappingCriterionTypeValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_feed",
            b"_feed",
            "criterion_type",
            b"criterion_type",
            "feed",
            b"feed",
            "placeholder_type",
            b"placeholder_type",
            "target",
            b"target",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_feed",
            b"_feed",
            "attribute_field_mappings",
            b"attribute_field_mappings",
            "criterion_type",
            b"criterion_type",
            "feed",
            b"feed",
            "placeholder_type",
            b"placeholder_type",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
            "target",
            b"target",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_feed", b"_feed"]
    ) -> typing_extensions___Literal["feed"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["target", b"target"]
    ) -> typing_extensions___Literal["placeholder_type", "criterion_type"]: ...

type___FeedMapping = FeedMapping

class AttributeFieldMapping(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    feed_attribute_id: builtin___int = ...
    field_id: builtin___int = ...
    sitelink_field: google___ads___googleads___v6___enums___sitelink_placeholder_field_pb2___SitelinkPlaceholderFieldEnum.SitelinkPlaceholderFieldValue = ...
    call_field: google___ads___googleads___v6___enums___call_placeholder_field_pb2___CallPlaceholderFieldEnum.CallPlaceholderFieldValue = ...
    app_field: google___ads___googleads___v6___enums___app_placeholder_field_pb2___AppPlaceholderFieldEnum.AppPlaceholderFieldValue = ...
    location_field: google___ads___googleads___v6___enums___location_placeholder_field_pb2___LocationPlaceholderFieldEnum.LocationPlaceholderFieldValue = ...
    affiliate_location_field: google___ads___googleads___v6___enums___affiliate_location_placeholder_field_pb2___AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderFieldValue = ...
    callout_field: google___ads___googleads___v6___enums___callout_placeholder_field_pb2___CalloutPlaceholderFieldEnum.CalloutPlaceholderFieldValue = ...
    structured_snippet_field: google___ads___googleads___v6___enums___structured_snippet_placeholder_field_pb2___StructuredSnippetPlaceholderFieldEnum.StructuredSnippetPlaceholderFieldValue = ...
    message_field: google___ads___googleads___v6___enums___message_placeholder_field_pb2___MessagePlaceholderFieldEnum.MessagePlaceholderFieldValue = ...
    price_field: google___ads___googleads___v6___enums___price_placeholder_field_pb2___PricePlaceholderFieldEnum.PricePlaceholderFieldValue = ...
    promotion_field: google___ads___googleads___v6___enums___promotion_placeholder_field_pb2___PromotionPlaceholderFieldEnum.PromotionPlaceholderFieldValue = ...
    ad_customizer_field: google___ads___googleads___v6___enums___ad_customizer_placeholder_field_pb2___AdCustomizerPlaceholderFieldEnum.AdCustomizerPlaceholderFieldValue = ...
    dsa_page_feed_field: google___ads___googleads___v6___enums___dsa_page_feed_criterion_field_pb2___DsaPageFeedCriterionFieldEnum.DsaPageFeedCriterionFieldValue = ...
    location_extension_targeting_field: google___ads___googleads___v6___enums___location_extension_targeting_criterion_field_pb2___LocationExtensionTargetingCriterionFieldEnum.LocationExtensionTargetingCriterionFieldValue = ...
    education_field: google___ads___googleads___v6___enums___education_placeholder_field_pb2___EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue = ...
    flight_field: google___ads___googleads___v6___enums___flight_placeholder_field_pb2___FlightPlaceholderFieldEnum.FlightPlaceholderFieldValue = ...
    custom_field: google___ads___googleads___v6___enums___custom_placeholder_field_pb2___CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue = ...
    hotel_field: google___ads___googleads___v6___enums___hotel_placeholder_field_pb2___HotelPlaceholderFieldEnum.HotelPlaceholderFieldValue = ...
    real_estate_field: google___ads___googleads___v6___enums___real_estate_placeholder_field_pb2___RealEstatePlaceholderFieldEnum.RealEstatePlaceholderFieldValue = ...
    travel_field: google___ads___googleads___v6___enums___travel_placeholder_field_pb2___TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue = ...
    local_field: google___ads___googleads___v6___enums___local_placeholder_field_pb2___LocalPlaceholderFieldEnum.LocalPlaceholderFieldValue = ...
    job_field: google___ads___googleads___v6___enums___job_placeholder_field_pb2___JobPlaceholderFieldEnum.JobPlaceholderFieldValue = ...
    def __init__(
        self,
        *,
        feed_attribute_id: typing___Optional[builtin___int] = None,
        field_id: typing___Optional[builtin___int] = None,
        sitelink_field: typing___Optional[
            google___ads___googleads___v6___enums___sitelink_placeholder_field_pb2___SitelinkPlaceholderFieldEnum.SitelinkPlaceholderFieldValue
        ] = None,
        call_field: typing___Optional[
            google___ads___googleads___v6___enums___call_placeholder_field_pb2___CallPlaceholderFieldEnum.CallPlaceholderFieldValue
        ] = None,
        app_field: typing___Optional[
            google___ads___googleads___v6___enums___app_placeholder_field_pb2___AppPlaceholderFieldEnum.AppPlaceholderFieldValue
        ] = None,
        location_field: typing___Optional[
            google___ads___googleads___v6___enums___location_placeholder_field_pb2___LocationPlaceholderFieldEnum.LocationPlaceholderFieldValue
        ] = None,
        affiliate_location_field: typing___Optional[
            google___ads___googleads___v6___enums___affiliate_location_placeholder_field_pb2___AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderFieldValue
        ] = None,
        callout_field: typing___Optional[
            google___ads___googleads___v6___enums___callout_placeholder_field_pb2___CalloutPlaceholderFieldEnum.CalloutPlaceholderFieldValue
        ] = None,
        structured_snippet_field: typing___Optional[
            google___ads___googleads___v6___enums___structured_snippet_placeholder_field_pb2___StructuredSnippetPlaceholderFieldEnum.StructuredSnippetPlaceholderFieldValue
        ] = None,
        message_field: typing___Optional[
            google___ads___googleads___v6___enums___message_placeholder_field_pb2___MessagePlaceholderFieldEnum.MessagePlaceholderFieldValue
        ] = None,
        price_field: typing___Optional[
            google___ads___googleads___v6___enums___price_placeholder_field_pb2___PricePlaceholderFieldEnum.PricePlaceholderFieldValue
        ] = None,
        promotion_field: typing___Optional[
            google___ads___googleads___v6___enums___promotion_placeholder_field_pb2___PromotionPlaceholderFieldEnum.PromotionPlaceholderFieldValue
        ] = None,
        ad_customizer_field: typing___Optional[
            google___ads___googleads___v6___enums___ad_customizer_placeholder_field_pb2___AdCustomizerPlaceholderFieldEnum.AdCustomizerPlaceholderFieldValue
        ] = None,
        dsa_page_feed_field: typing___Optional[
            google___ads___googleads___v6___enums___dsa_page_feed_criterion_field_pb2___DsaPageFeedCriterionFieldEnum.DsaPageFeedCriterionFieldValue
        ] = None,
        location_extension_targeting_field: typing___Optional[
            google___ads___googleads___v6___enums___location_extension_targeting_criterion_field_pb2___LocationExtensionTargetingCriterionFieldEnum.LocationExtensionTargetingCriterionFieldValue
        ] = None,
        education_field: typing___Optional[
            google___ads___googleads___v6___enums___education_placeholder_field_pb2___EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue
        ] = None,
        flight_field: typing___Optional[
            google___ads___googleads___v6___enums___flight_placeholder_field_pb2___FlightPlaceholderFieldEnum.FlightPlaceholderFieldValue
        ] = None,
        custom_field: typing___Optional[
            google___ads___googleads___v6___enums___custom_placeholder_field_pb2___CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue
        ] = None,
        hotel_field: typing___Optional[
            google___ads___googleads___v6___enums___hotel_placeholder_field_pb2___HotelPlaceholderFieldEnum.HotelPlaceholderFieldValue
        ] = None,
        real_estate_field: typing___Optional[
            google___ads___googleads___v6___enums___real_estate_placeholder_field_pb2___RealEstatePlaceholderFieldEnum.RealEstatePlaceholderFieldValue
        ] = None,
        travel_field: typing___Optional[
            google___ads___googleads___v6___enums___travel_placeholder_field_pb2___TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue
        ] = None,
        local_field: typing___Optional[
            google___ads___googleads___v6___enums___local_placeholder_field_pb2___LocalPlaceholderFieldEnum.LocalPlaceholderFieldValue
        ] = None,
        job_field: typing___Optional[
            google___ads___googleads___v6___enums___job_placeholder_field_pb2___JobPlaceholderFieldEnum.JobPlaceholderFieldValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_feed_attribute_id",
            b"_feed_attribute_id",
            "_field_id",
            b"_field_id",
            "ad_customizer_field",
            b"ad_customizer_field",
            "affiliate_location_field",
            b"affiliate_location_field",
            "app_field",
            b"app_field",
            "call_field",
            b"call_field",
            "callout_field",
            b"callout_field",
            "custom_field",
            b"custom_field",
            "dsa_page_feed_field",
            b"dsa_page_feed_field",
            "education_field",
            b"education_field",
            "feed_attribute_id",
            b"feed_attribute_id",
            "field",
            b"field",
            "field_id",
            b"field_id",
            "flight_field",
            b"flight_field",
            "hotel_field",
            b"hotel_field",
            "job_field",
            b"job_field",
            "local_field",
            b"local_field",
            "location_extension_targeting_field",
            b"location_extension_targeting_field",
            "location_field",
            b"location_field",
            "message_field",
            b"message_field",
            "price_field",
            b"price_field",
            "promotion_field",
            b"promotion_field",
            "real_estate_field",
            b"real_estate_field",
            "sitelink_field",
            b"sitelink_field",
            "structured_snippet_field",
            b"structured_snippet_field",
            "travel_field",
            b"travel_field",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_feed_attribute_id",
            b"_feed_attribute_id",
            "_field_id",
            b"_field_id",
            "ad_customizer_field",
            b"ad_customizer_field",
            "affiliate_location_field",
            b"affiliate_location_field",
            "app_field",
            b"app_field",
            "call_field",
            b"call_field",
            "callout_field",
            b"callout_field",
            "custom_field",
            b"custom_field",
            "dsa_page_feed_field",
            b"dsa_page_feed_field",
            "education_field",
            b"education_field",
            "feed_attribute_id",
            b"feed_attribute_id",
            "field",
            b"field",
            "field_id",
            b"field_id",
            "flight_field",
            b"flight_field",
            "hotel_field",
            b"hotel_field",
            "job_field",
            b"job_field",
            "local_field",
            b"local_field",
            "location_extension_targeting_field",
            b"location_extension_targeting_field",
            "location_field",
            b"location_field",
            "message_field",
            b"message_field",
            "price_field",
            b"price_field",
            "promotion_field",
            b"promotion_field",
            "real_estate_field",
            b"real_estate_field",
            "sitelink_field",
            b"sitelink_field",
            "structured_snippet_field",
            b"structured_snippet_field",
            "travel_field",
            b"travel_field",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_feed_attribute_id", b"_feed_attribute_id"
        ],
    ) -> typing_extensions___Literal["feed_attribute_id"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_field_id", b"_field_id"]
    ) -> typing_extensions___Literal["field_id"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["field", b"field"]
    ) -> typing_extensions___Literal[
        "sitelink_field",
        "call_field",
        "app_field",
        "location_field",
        "affiliate_location_field",
        "callout_field",
        "structured_snippet_field",
        "message_field",
        "price_field",
        "promotion_field",
        "ad_customizer_field",
        "dsa_page_feed_field",
        "location_extension_targeting_field",
        "education_field",
        "flight_field",
        "custom_field",
        "hotel_field",
        "real_estate_field",
        "travel_field",
        "local_field",
        "job_field",
    ]: ...

type___AttributeFieldMapping = AttributeFieldMapping



from typing import Any

class CarrierConstantServiceStub:
    GetCarrierConstant: Any = ...
    def __init__(self, channel: Any) -> None: ...

class CarrierConstantServiceServicer:
    def GetCarrierConstant(self, request: Any, context: Any) -> None: ...

def add_CarrierConstantServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class CriterionCategoryLocaleAvailabilityModeEnum(
    google___protobuf___message___Message
):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    CriterionCategoryLocaleAvailabilityModeValue = typing___NewType(
        "CriterionCategoryLocaleAvailabilityModeValue", builtin___int
    )
    type___CriterionCategoryLocaleAvailabilityModeValue = (
        CriterionCategoryLocaleAvailabilityModeValue
    )
    CriterionCategoryLocaleAvailabilityMode: _CriterionCategoryLocaleAvailabilityMode
    class _CriterionCategoryLocaleAvailabilityMode(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            CriterionCategoryLocaleAvailabilityModeEnum.CriterionCategoryLocaleAvailabilityModeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            CriterionCategoryLocaleAvailabilityModeEnum.CriterionCategoryLocaleAvailabilityModeValue,
            0,
        )
        UNKNOWN = typing___cast(
            CriterionCategoryLocaleAvailabilityModeEnum.CriterionCategoryLocaleAvailabilityModeValue,
            1,
        )
        ALL_LOCALES = typing___cast(
            CriterionCategoryLocaleAvailabilityModeEnum.CriterionCategoryLocaleAvailabilityModeValue,
            2,
        )
        COUNTRY_AND_ALL_LANGUAGES = typing___cast(
            CriterionCategoryLocaleAvailabilityModeEnum.CriterionCategoryLocaleAvailabilityModeValue,
            3,
        )
        LANGUAGE_AND_ALL_COUNTRIES = typing___cast(
            CriterionCategoryLocaleAvailabilityModeEnum.CriterionCategoryLocaleAvailabilityModeValue,
            4,
        )
        COUNTRY_AND_LANGUAGE = typing___cast(
            CriterionCategoryLocaleAvailabilityModeEnum.CriterionCategoryLocaleAvailabilityModeValue,
            5,
        )
    UNSPECIFIED = typing___cast(
        CriterionCategoryLocaleAvailabilityModeEnum.CriterionCategoryLocaleAvailabilityModeValue,
        0,
    )
    UNKNOWN = typing___cast(
        CriterionCategoryLocaleAvailabilityModeEnum.CriterionCategoryLocaleAvailabilityModeValue,
        1,
    )
    ALL_LOCALES = typing___cast(
        CriterionCategoryLocaleAvailabilityModeEnum.CriterionCategoryLocaleAvailabilityModeValue,
        2,
    )
    COUNTRY_AND_ALL_LANGUAGES = typing___cast(
        CriterionCategoryLocaleAvailabilityModeEnum.CriterionCategoryLocaleAvailabilityModeValue,
        3,
    )
    LANGUAGE_AND_ALL_COUNTRIES = typing___cast(
        CriterionCategoryLocaleAvailabilityModeEnum.CriterionCategoryLocaleAvailabilityModeValue,
        4,
    )
    COUNTRY_AND_LANGUAGE = typing___cast(
        CriterionCategoryLocaleAvailabilityModeEnum.CriterionCategoryLocaleAvailabilityModeValue,
        5,
    )
    type___CriterionCategoryLocaleAvailabilityMode = (
        CriterionCategoryLocaleAvailabilityMode
    )
    def __init__(self,) -> None: ...

type___CriterionCategoryLocaleAvailabilityModeEnum = (
    CriterionCategoryLocaleAvailabilityModeEnum
)



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class LanguageCodeErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    LanguageCodeErrorValue = typing___NewType("LanguageCodeErrorValue", builtin___int)
    type___LanguageCodeErrorValue = LanguageCodeErrorValue
    LanguageCodeError: _LanguageCodeError
    class _LanguageCodeError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            LanguageCodeErrorEnum.LanguageCodeErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(LanguageCodeErrorEnum.LanguageCodeErrorValue, 0)
        UNKNOWN = typing___cast(LanguageCodeErrorEnum.LanguageCodeErrorValue, 1)
        LANGUAGE_CODE_NOT_FOUND = typing___cast(
            LanguageCodeErrorEnum.LanguageCodeErrorValue, 2
        )
        INVALID_LANGUAGE_CODE = typing___cast(
            LanguageCodeErrorEnum.LanguageCodeErrorValue, 3
        )
    UNSPECIFIED = typing___cast(LanguageCodeErrorEnum.LanguageCodeErrorValue, 0)
    UNKNOWN = typing___cast(LanguageCodeErrorEnum.LanguageCodeErrorValue, 1)
    LANGUAGE_CODE_NOT_FOUND = typing___cast(
        LanguageCodeErrorEnum.LanguageCodeErrorValue, 2
    )
    INVALID_LANGUAGE_CODE = typing___cast(
        LanguageCodeErrorEnum.LanguageCodeErrorValue, 3
    )
    type___LanguageCodeError = LanguageCodeError
    def __init__(self,) -> None: ...

type___LanguageCodeErrorEnum = LanguageCodeErrorEnum
